@@ -18,6 +18,7 @@ from hamcrest import (
 )
 
 from features.environment import (
+    build_debs_from_sbuild,
     capture_container_as_image,
     create_instance_with_uat_installed,
 )
@@ -34,6 +35,8 @@ CONTAINER_PREFIX = "ubuntu-behave-test"
 IMAGE_BUILD_PREFIX = "ubuntu-behave-image-build"
 IMAGE_PREFIX = "ubuntu-behave-image"
 
+ERROR_CODE = "1"
+
 
 def add_test_name_suffix(context, series, prefix):
     pr_number = os.environ.get("UACLIENT_BEHAVE_JENKINS_CHANGE_ID")
@@ -131,6 +134,56 @@ def given_a_machine(context, series):
     )
 
 
+@when("I have the `{series}` debs under test in `{dest}`")
+def when_i_have_the_debs_under_test(context, series, dest):
+    if context.config.build_pr:
+        deb_paths = build_debs_from_sbuild(context, series)
+
+        for deb_path in deb_paths:
+            tools_or_pro = "tools" if "tools" in deb_path else "pro"
+            dest_path = "{}/ubuntu-advantage-{}.deb".format(dest, tools_or_pro)
+            context.instances["uaclient"].push_file(deb_path, dest_path)
+    else:
+        if context.config.enable_proposed:
+            ppa_opts = ""
+        else:
+            if context.config.ppa.startswith("ppa"):
+                ppa = context.config.ppa
+            else:
+                # assumes format "http://domain.name/user/ppa/ubuntu"
+                match = re.match(
+                    r"https?://[\w.]+/([^/]+/[^/]+)", context.config.ppa
+                )
+                if not match:
+                    raise AssertionError(
+                        "ppa is in unsupported format: {}".format(
+                            context.config.ppa
+                        )
+                    )
+                ppa = "ppa:{}".format(match.group(1))
+            ppa_opts = "--distro ppa --ppa {}".format(ppa)
+        download_cmd = "pull-lp-debs {} ubuntu-advantage-tools {}".format(
+            ppa_opts, series
+        )
+        when_i_run_command(
+            context, "apt-get install -y ubuntu-dev-tools", "with sudo"
+        )
+        when_i_run_command(context, download_cmd, "with sudo")
+        logging.info("Download command `{}`".format(download_cmd))
+        logging.info("stdout: {}".format(context.process.stdout))
+        logging.info("stderr: {}".format(context.process.stderr))
+        when_i_run_shell_command(
+            context,
+            "cp ubuntu-advantage-tools*.deb ubuntu-advantage-tools.deb",
+            "with sudo",
+        )
+        when_i_run_shell_command(
+            context,
+            "cp ubuntu-advantage-pro*.deb ubuntu-advantage-pro.deb",
+            "with sudo",
+        )
+
+
 @when(
     "I launch a `{series}` `{instance_name}` machine with ingress ports `{ports}`"  # noqa
 )
@@ -309,6 +362,11 @@ def when_i_run_command(
     context.process = process
 
 
+@when("I run shell command `{command}` {user_spec}")
+def when_i_run_shell_command(context, command, user_spec):
+    when_i_run_command(context, 'sh -c "{}"'.format(command), user_spec)
+
+
 @when("I fix `{issue}` by attaching to a subscription with `{token_type}`")
 def when_i_fix_a_issue_by_attaching(context, issue, token_type):
     token = getattr(context.config, token_type)
@@ -477,6 +535,9 @@ def when_i_wait(context, seconds):
 
 @when("I replace `{original}` in `{filename}` with `{new}`")
 def when_i_replace_string_in_file(context, original, filename, new):
+    new = new.replace("\\", r"\\")
+    new = new.replace("/", r"\/")
+    new = new.replace("&", r"\&")
     when_i_run_command(
         context,
         "sed -i 's/{original}/{new}/' {filename}".format(
@@ -522,7 +583,10 @@ def then_stream_does_not_match_regexp(context, stream):
 @then("{stream} matches regexp")
 def then_stream_matches_regexp(context, stream):
     content = getattr(context.process, stream).strip()
-    assert_that(content, matches_regexp(context.text))
+    text = context.text
+    if "<ci-proxy-ip>" in text and "proxy" in context.instances:
+        text = text.replace("<ci-proxy-ip>", context.instances["proxy"].ip)
+    assert_that(content, matches_regexp(text))
 
 
 @then("{stream} contains substring")
@@ -589,6 +653,19 @@ def when_i_verify_attach_with_json_response(context, spec, exit_codes):
     )
 
 
+@when(
+    "I verify that running attach `{spec}` using expired token with json response fails"  # noqa
+)
+def when_i_verify_attach_expired_token_with_json_response(context, spec):
+    change_contract_endpoint_to_staging(context, user_spec="with sudo")
+    cmd = "ua attach {} --format json".format(
+        context.config.contract_token_staging_expired
+    )
+    then_i_verify_that_running_cmd_with_spec_exits_with_codes(
+        context=context, cmd_name=cmd, spec=spec, exit_codes=ERROR_CODE
+    )
+
+
 @when(
     "I verify that running `{cmd_name}` `{spec}` and stdin `{stdin}` exits `{exit_codes}`"  # noqa
 )
@@ -882,6 +959,109 @@ def stdout_matches_the_json_schema(context, output_format, schema):
         jsonschema.validate(instance=instance, schema=json.load(schema_file))
 
 
+@then("`{file_name}` is not present in any docker image layer")
+def file_is_not_present_in_any_docker_image_layer(context, file_name):
+    when_i_run_command(
+        context,
+        "find /var/lib/docker/overlay2 -name {}".format(file_name),
+        "with sudo",
+    )
+    results = context.process.stdout.strip()
+    if results:
+        raise AssertionError(
+            'found "{}"'.format(", ".join(results.split("\n")))
+        )
+
+
+# This defines "not significantly larger" as "less than 2MB larger"
+@then(
+    "docker image `{name}` is not significantly larger than `ubuntu:{series}` with `{package}` installed"  # noqa: E501
+)
+def docker_image_is_not_larger(context, name, series, package):
+    base_image_name = "ubuntu:{}".format(series)
+    base_upgraded_image_name = "{}-with-test-package".format(series)
+
+    # We need to compare against the base image after apt upgrade
+    # and package install
+    dockerfile = """\
+    FROM {}
+    RUN apt-get update \\
+      && apt-get install -y {} \\
+      && rm -rf /var/lib/apt/lists/*
+    """.format(
+        base_image_name, package
+    )
+    context.text = dockerfile
+    when_i_create_file_with_content(context, "Dockerfile.base")
+    when_i_run_command(
+        context,
+        "docker build . -f Dockerfile.base -t {}".format(
+            base_upgraded_image_name
+        ),
+        "with sudo",
+    )
+
+    # find image sizes
+    when_i_run_shell_command(
+        context, "docker inspect {} | jq .[0].Size".format(name), "with sudo"
+    )
+    custom_image_size = int(context.process.stdout.strip())
+    when_i_run_shell_command(
+        context,
+        "docker inspect {} | jq .[0].Size".format(base_upgraded_image_name),
+        "with sudo",
+    )
+    base_image_size = int(context.process.stdout.strip())
+
+    # Get ua test deb size
+    when_i_run_command(context, "du ubuntu-advantage-tools.deb", "with sudo")
+    # Example out: "1234\tubuntu-advantage-tools.deb"
+    ua_test_deb_size = (
+        int(context.process.stdout.strip().split("\t")[0]) * 1024
+    )  # KB -> B
+
+    # Give us some space for bloat we don't control: 2MB -> B
+    extra_space = 2 * 1024 * 1024
+
+    if custom_image_size > (base_image_size + ua_test_deb_size + extra_space):
+        raise AssertionError(
+            "Custom image size ({}) is over 2MB greater than the base image"
+            " size ({}) + ua test deb size ({})".format(
+                custom_image_size, base_image_size, ua_test_deb_size
+            )
+        )
+    logging.debug(
+        "custom image size ({})\n"
+        "base image size ({})\n"
+        "ua test deb size ({})".format(
+            custom_image_size, base_image_size, ua_test_deb_size
+        )
+    )
+
+
+@then(
+    "on `{release}`, systemd status output says memory usage is less than `{mb_limit}` MB"  # noqa
+)
+def systemd_memory_usage_less_than(context, release, mb_limit):
+    curr_release = context.active_outline["release"]
+    if release != curr_release:
+        logging.debug("Skipping for {}".format(curr_release))
+        return
+    match = re.search(r"Memory: (.*)M", context.process.stdout.strip())
+    if match is None:
+        raise AssertionError(
+            "Memory usage not present in current process stdout"
+        )
+    mb_used = float(match.group(1))
+    logging.debug("Found {}M".format(mb_used))
+
+    mb_limit_float = float(mb_limit)
+    if mb_used > mb_limit_float:
+        raise AssertionError(
+            "Using more memory than expected ({}M)".format(mb_used)
+        )
+
+
 def get_command_prefix_for_user_spec(user_spec):
     prefix = []
     if user_spec == "with sudo":
