@@ -3,8 +3,9 @@
 import mock
 import pytest
 
-from uaclient import apt, status
+from uaclient import apt, messages
 from uaclient.entitlements.cis import CIS_DOCS_URL, CISEntitlement
+from uaclient.entitlements.entitlement_status import ApplicationStatus
 
 M_REPOPATH = "uaclient.entitlements.repo."
 
@@ -28,13 +29,14 @@ class TestCISEntitlementCanEnable:
         with mock.patch.object(
             entitlement,
             "application_status",
-            return_value=(status.ApplicationStatus.DISABLED, ""),
+            return_value=(ApplicationStatus.DISABLED, ""),
         ):
             assert entitlement.can_enable()
         assert ("", "") == capsys.readouterr()
 
 
 class TestCISEntitlementEnable:
+    @mock.patch("uaclient.apt.run_apt_cache_policy_command")
     @mock.patch("uaclient.apt.setup_apt_proxy")
     @mock.patch("uaclient.util.should_reboot")
     @mock.patch("uaclient.util.subp")
@@ -45,6 +47,7 @@ class TestCISEntitlementEnable:
         m_subp,
         m_should_reboot,
         m_setup_apt_proxy,
+        m_apt_policy,
         capsys,
         entitlement,
     ):
@@ -58,6 +61,7 @@ class TestCISEntitlementEnable:
 
         m_platform_info.side_effect = fake_platform
         m_subp.return_value = ("fakeout", "")
+        m_apt_policy.return_value = "fakeout"
         m_should_reboot.return_value = False
 
         with mock.patch(
@@ -77,13 +81,13 @@ class TestCISEntitlementEnable:
             )
         ]
 
-        subp_apt_cmds = [
+        m_apt_policy_cmds = [
             mock.call(
-                ["apt-cache", "policy"],
-                capture=True,
-                retry_sleeps=apt.APT_RETRIES,
-                env={},
+                error_msg=messages.APT_POLICY_FAILED.msg,
             ),
+        ]
+
+        subp_apt_cmds = [
             mock.call(
                 ["apt-get", "update"],
                 capture=True,
@@ -111,6 +115,8 @@ class TestCISEntitlementEnable:
         assert [] == m_add_pin.call_args_list
         assert 1 == m_setup_apt_proxy.call_count
         assert subp_apt_cmds == m_subp.call_args_list
+        assert 1 == m_apt_policy.call_count
+        assert m_apt_policy_cmds == m_apt_policy.call_args_list
         assert 1 == m_should_reboot.call_count
         expected_stdout = (
             "Updating package lists\n"
