@@ -10,8 +10,13 @@ from functools import partial
 import mock
 import pytest
 
-from uaclient import apt, defaults, exceptions, messages, status, util
+from uaclient import apt, defaults, exceptions, messages, util
 from uaclient.clouds.identity import NoCloudTypeReason
+from uaclient.entitlements.entitlement_status import (
+    ApplicabilityStatus,
+    ApplicationStatus,
+    CanEnableFailureReason,
+)
 from uaclient.entitlements.fips import (
     CONDITIONAL_PACKAGES_EVERYWHERE,
     CONDITIONAL_PACKAGES_OPENSSH_HMAC,
@@ -125,7 +130,7 @@ class TestFIPSEntitlementDefaults:
                         util.prompt_for_confirmation,
                         {
                             "assume_yes": assume_yes,
-                            "msg": status.PROMPT_FIPS_PRE_ENABLE,
+                            "msg": messages.PROMPT_FIPS_PRE_ENABLE,
                         },
                     )
                 ],
@@ -135,7 +140,7 @@ class TestFIPSEntitlementDefaults:
                         util.prompt_for_confirmation,
                         {
                             "assume_yes": assume_yes,
-                            "msg": status.PROMPT_FIPS_PRE_DISABLE,
+                            "msg": messages.PROMPT_FIPS_PRE_DISABLE,
                         },
                     )
                 ],
@@ -145,7 +150,7 @@ class TestFIPSEntitlementDefaults:
                     (
                         util.prompt_for_confirmation,
                         {
-                            "msg": status.PROMPT_FIPS_UPDATES_PRE_ENABLE,
+                            "msg": messages.PROMPT_FIPS_UPDATES_PRE_ENABLE,
                             "assume_yes": assume_yes,
                         },
                     )
@@ -156,7 +161,7 @@ class TestFIPSEntitlementDefaults:
                         util.prompt_for_confirmation,
                         {
                             "assume_yes": assume_yes,
-                            "msg": status.PROMPT_FIPS_PRE_DISABLE,
+                            "msg": messages.PROMPT_FIPS_PRE_DISABLE,
                         },
                     )
                 ],
@@ -182,7 +187,7 @@ class TestFIPSEntitlementDefaults:
                         util.prompt_for_confirmation,
                         {
                             "assume_yes": False,
-                            "msg": status.PROMPT_FIPS_CONTAINER_PRE_ENABLE.format(  # noqa: E501
+                            "msg": messages.PROMPT_FIPS_CONTAINER_PRE_ENABLE.format(  # noqa: E501
                                 title="FIPS"
                             ),
                         },
@@ -194,7 +199,7 @@ class TestFIPSEntitlementDefaults:
                         util.prompt_for_confirmation,
                         {
                             "assume_yes": False,
-                            "msg": status.PROMPT_FIPS_PRE_DISABLE,
+                            "msg": messages.PROMPT_FIPS_PRE_DISABLE,
                         },
                     )
                 ],
@@ -204,7 +209,7 @@ class TestFIPSEntitlementDefaults:
                     (
                         util.prompt_for_confirmation,
                         {
-                            "msg": status.PROMPT_FIPS_CONTAINER_PRE_ENABLE.format(  # noqa: E501
+                            "msg": messages.PROMPT_FIPS_CONTAINER_PRE_ENABLE.format(  # noqa: E501
                                 title="FIPS Updates"
                             ),
                             "assume_yes": False,
@@ -217,7 +222,7 @@ class TestFIPSEntitlementDefaults:
                         util.prompt_for_confirmation,
                         {
                             "assume_yes": False,
-                            "msg": status.PROMPT_FIPS_PRE_DISABLE,
+                            "msg": messages.PROMPT_FIPS_PRE_DISABLE,
                         },
                     )
                 ],
@@ -239,12 +244,12 @@ class TestFIPSEntitlementCanEnable:
         with mock.patch.object(
             entitlement,
             "applicability_status",
-            return_value=(status.ApplicabilityStatus.APPLICABLE, ""),
+            return_value=(ApplicabilityStatus.APPLICABLE, ""),
         ):
             with mock.patch.object(
                 entitlement,
                 "application_status",
-                return_value=(status.ApplicationStatus.DISABLED, ""),
+                return_value=(ApplicationStatus.DISABLED, ""),
             ):
                 with mock.patch.object(
                     entitlement,
@@ -302,9 +307,11 @@ class TestFIPSEntitlementEnable:
             stack.enter_context(
                 mock.patch.object(type(entitlement), "packages", m_packages)
             )
+            stack.enter_context(
+                mock.patch("uaclient.util.is_container", return_value=False)
+            )
 
             m_can_enable.return_value = (True, None)
-
             assert (True, None) == entitlement.enable()
 
         repo_url = "http://{}".format(entitlement.name.upper())
@@ -364,27 +371,20 @@ class TestFIPSEntitlementEnable:
                 )
             )
 
-        if isinstance(entitlement, FIPSEntitlement):
-            subp_calls = [
-                mock.call(
-                    ["apt-mark", "showholds"],
-                    capture=True,
-                    retry_sleeps=apt.APT_RETRIES,
-                    env={},
-                )
-            ]
-        else:
-            subp_calls = []
-        subp_calls.extend(
-            [
-                mock.call(
-                    ["apt-get", "update"],
-                    capture=True,
-                    retry_sleeps=apt.APT_RETRIES,
-                    env={},
-                )
-            ]
-        )
+        subp_calls = [
+            mock.call(
+                ["apt-mark", "showholds"],
+                capture=True,
+                retry_sleeps=apt.APT_RETRIES,
+                env={},
+            ),
+            mock.call(
+                ["apt-get", "update"],
+                capture=True,
+                retry_sleeps=apt.APT_RETRIES,
+                env={},
+            ),
+        ]
         subp_calls += install_cmd
 
         assert [mock.call()] == m_can_enable.call_args_list
@@ -429,7 +429,12 @@ class TestFIPSEntitlementEnable:
         [
             (
                 True,
-                [mock.call("", status.NOTICE_WRONG_FIPS_METAPACKAGE_ON_CLOUD)],
+                [
+                    mock.call(
+                        "", messages.NOTICE_WRONG_FIPS_METAPACKAGE_ON_CLOUD
+                    ),
+                    mock.call("", messages.FIPS_REBOOT_REQUIRED_MSG),
+                ],
             ),
             (False, []),
         ],
@@ -447,7 +452,7 @@ class TestFIPSEntitlementEnable:
         m_repo_enable.return_value = repo_enable_return_value
         assert repo_enable_return_value is entitlement._perform_enable()
         assert (
-            expected_remove_notice_calls == m_remove_notice.call_args_list[:1]
+            expected_remove_notice_calls == m_remove_notice.call_args_list[:2]
         )
 
     @mock.patch("uaclient.apt.setup_apt_proxy")
@@ -595,10 +600,10 @@ class TestFIPSEntitlementEnable:
             with mock.patch.object(
                 fips_ent,
                 "applicability_status",
-                return_value=(status.ApplicabilityStatus.APPLICABLE, ""),
+                return_value=(ApplicabilityStatus.APPLICABLE, ""),
             ):
                 m_livepatch.return_value = (
-                    status.ApplicationStatus.ENABLED,
+                    ApplicationStatus.ENABLED,
                     "",
                 )
                 ret, fail = fips_ent.enable()
@@ -610,7 +615,7 @@ class TestFIPSEntitlementEnable:
     @mock.patch("uaclient.util.handle_message_operations")
     @mock.patch(
         M_LIVEPATCH_PATH + "application_status",
-        return_value=((status.ApplicationStatus.DISABLED, "")),
+        return_value=((ApplicationStatus.DISABLED, "")),
     )
     @mock.patch("uaclient.util.is_container", return_value=False)
     def test_enable_fails_when_fips_update_service_is_enabled(
@@ -632,7 +637,7 @@ class TestFIPSEntitlementEnable:
             ) as m_allow_fips_on_cloud:
                 m_allow_fips_on_cloud.return_value = True
                 m_fips_update.return_value = (
-                    status.ApplicationStatus.ENABLED,
+                    ApplicationStatus.ENABLED,
                     "",
                 )
                 result, reason = fips_entitlement.enable()
@@ -645,7 +650,7 @@ class TestFIPSEntitlementEnable:
     @mock.patch("uaclient.util.handle_message_operations")
     @mock.patch(
         M_LIVEPATCH_PATH + "application_status",
-        return_value=((status.ApplicationStatus.DISABLED, "")),
+        return_value=((ApplicationStatus.DISABLED, "")),
     )
     @mock.patch("uaclient.util.is_container", return_value=False)
     def test_enable_fails_when_fips_updates_service_once_enabled(
@@ -684,18 +689,18 @@ class TestFIPSEntitlementEnable:
         entitlement,
     ):
         m_handle_message_op.return_value = True
-        m_cloud_type.return_value = ("azure", None)
+        m_cloud_type.return_value = ("gce", None)
         m_platform_info.return_value = {"series": "xenial"}
         base_path = "uaclient.entitlements.livepatch.LivepatchEntitlement"
 
         with mock.patch(
             "{}.application_status".format(base_path)
         ) as m_livepatch:
-            m_livepatch.return_value = (status.ApplicationStatus.DISABLED, "")
+            m_livepatch.return_value = (ApplicationStatus.DISABLED, "")
             result, reason = entitlement.enable()
             assert not result
             expected_msg = """\
-            Ubuntu Xenial does not provide an Azure optimized FIPS kernel"""
+            Ubuntu Xenial does not provide a GCP optimized FIPS kernel"""
             assert expected_msg.strip() in reason.message.msg.strip()
 
     @mock.patch("uaclient.util.get_platform_info")
@@ -726,7 +731,7 @@ class TestFIPSEntitlementEnable:
             "{}.application_status".format(base_path)
         ) as m_fips_status:
             m_fips_status.return_value = (
-                status.ApplicationStatus.DISABLED,
+                ApplicationStatus.DISABLED,
                 "",
             )
             result, reason = entitlement.enable()
@@ -735,7 +740,9 @@ class TestFIPSEntitlementEnable:
             Ubuntu Test does not provide a GCP optimized FIPS kernel"""
             assert expected_msg.strip() in reason.message.msg.strip()
 
-    @pytest.mark.parametrize("allow_xenial_fips_on_cloud", ((True), (False)))
+    @pytest.mark.parametrize(
+        "allow_default_fips_metapackage_on_gcp", ((True), (False))
+    )
     @pytest.mark.parametrize("cloud_id", (("aws"), ("gce"), ("azure"), (None)))
     @pytest.mark.parametrize("series", (("xenial"), ("bionic")))
     @mock.patch("uaclient.util.is_config_value_true")
@@ -744,12 +751,12 @@ class TestFIPSEntitlementEnable:
         m_is_config_value_true,
         series,
         cloud_id,
-        allow_xenial_fips_on_cloud,
+        allow_default_fips_metapackage_on_gcp,
         entitlement,
     ):
         def mock_config_value(config, path_to_value):
-            if "allow_xenial_fips_on_cloud" in path_to_value:
-                return allow_xenial_fips_on_cloud
+            if "allow_default_fips_metapackage_on_gcp" in path_to_value:
+                return allow_default_fips_metapackage_on_gcp
 
             return False
 
@@ -758,18 +765,20 @@ class TestFIPSEntitlementEnable:
             cloud_id=cloud_id, series=series
         )
 
-        if cloud_id == "aws" or cloud_id is None:
+        if cloud_id in ("azure", "aws") or cloud_id is None:
             assert actual_value
-        elif cloud_id == "gce" and series != "bionic":
+        elif all([cloud_id == "gce", allow_default_fips_metapackage_on_gcp]):
+            assert actual_value
+        elif all(
+            [
+                cloud_id == "gce",
+                not allow_default_fips_metapackage_on_gcp,
+                series == "xenial",
+            ]
+        ):
             assert not actual_value
         elif cloud_id == "gce":
             assert actual_value
-        elif all([allow_xenial_fips_on_cloud, series == "xenial"]):
-            assert actual_value
-        elif series == "xenial":
-            assert not actual_value
-        else:
-            assert actual_value
 
     @pytest.mark.parametrize(
         "cfg_allow_default_fips_metapkg_on_gcp", ((True), (False))
@@ -916,11 +925,7 @@ class TestFIPSEntitlementDisable:
 class TestFIPSEntitlementApplicationStatus:
     @pytest.mark.parametrize(
         "super_application_status",
-        [
-            s
-            for s in status.ApplicationStatus
-            if s is not status.ApplicationStatus.ENABLED
-        ],
+        [s for s in ApplicationStatus if s is not ApplicationStatus.ENABLED],
     )
     def test_non_enabled_passed_through(
         self, entitlement, super_application_status
@@ -958,6 +963,9 @@ class TestFIPSEntitlementApplicationStatus:
             "", messages.FIPS_SYSTEM_REBOOT_REQUIRED.msg
         )
 
+        if path_exists:
+            entitlement.cfg.add_notice("", messages.FIPS_REBOOT_REQUIRED_MSG)
+
         if proc_content == "0":
             entitlement.cfg.add_notice(
                 "", messages.FIPS_DISABLE_REBOOT_REQUIRED
@@ -965,17 +973,18 @@ class TestFIPSEntitlementApplicationStatus:
 
         with mock.patch(
             M_PATH + "repo.RepoEntitlement.application_status",
-            return_value=(status.ApplicationStatus.ENABLED, msg),
+            return_value=(ApplicationStatus.ENABLED, msg),
         ):
             with mock.patch("uaclient.util.load_file") as m_load_file:
                 m_load_file.side_effect = fake_load_file
                 with mock.patch("os.path.exists") as m_path_exists:
                     m_path_exists.side_effect = fake_exists
-                    actual_status, actual_msg = (
-                        entitlement.application_status()
-                    )
+                    (
+                        actual_status,
+                        actual_msg,
+                    ) = entitlement.application_status()
 
-        expected_status = status.ApplicationStatus.ENABLED
+        expected_status = ApplicationStatus.ENABLED
         if path_exists and proc_content == "1":
             expected_msg = msg
             assert entitlement.cfg.read_cache("notices") is None
@@ -983,9 +992,9 @@ class TestFIPSEntitlementApplicationStatus:
             expected_msg = messages.FIPS_PROC_FILE_ERROR.format(
                 file_name=entitlement.FIPS_PROC_FILE
             )
-            expected_status = status.ApplicationStatus.DISABLED
+            expected_status = ApplicationStatus.DISABLED
             assert [
-                ["", status.NOTICE_FIPS_MANUAL_DISABLE_URL]
+                ["", messages.NOTICE_FIPS_MANUAL_DISABLE_URL]
             ] == entitlement.cfg.read_cache("notices")
         else:
             expected_msg = messages.FIPS_REBOOT_REQUIRED
@@ -1000,18 +1009,20 @@ class TestFIPSEntitlementApplicationStatus:
     def test_fips_does_not_show_enabled_when_fips_updates_is(
         self, entitlement
     ):
-        with mock.patch(M_PATH + "util.subp") as m_subp:
-            m_subp.return_value = (
+        with mock.patch(
+            "uaclient.apt.run_apt_cache_policy_command"
+        ) as m_apt_policy:
+            m_apt_policy.return_value = (
                 "1001 http://FIPS-UPDATES/ubuntu"
-                " xenial-updates/main amd64 Packages\n",
-                "",
+                " xenial-updates/main amd64 Packages\n"
+                ""
             )
 
             application_status, _ = entitlement.application_status()
 
-        expected_status = status.ApplicationStatus.DISABLED
+        expected_status = ApplicationStatus.DISABLED
         if isinstance(entitlement, FIPSUpdatesEntitlement):
-            expected_status = status.ApplicationStatus.ENABLED
+            expected_status = ApplicationStatus.ENABLED
 
         assert expected_status == application_status
 
@@ -1092,6 +1103,10 @@ class TestFipsSetupAPTConfig:
                 "openssh-server\nlibssl1.1-hmac\nasdf\n",
                 ["openssh-server", "libssl1.1-hmac"],
             ),
+            (
+                "libgcrypt20\nlibgcrypt20-hmac\nwow\n",
+                ["libgcrypt20", "libgcrypt20-hmac"],
+            ),
         ),
     )
     @mock.patch(M_REPOPATH + "RepoEntitlement.setup_apt_config")
@@ -1107,19 +1122,12 @@ class TestFipsSetupAPTConfig:
         """Unmark only fips-specific package holds if present."""
         run_apt_command.return_value = held_packages
         entitlement.setup_apt_config(silent=False)
-        if isinstance(entitlement, FIPSUpdatesEntitlement):
-            expected_calls = []
-        else:
-            expected_calls = [
-                mock.call(
-                    ["apt-mark", "showholds"], "apt-mark showholds failed."
-                )
-            ]
-            if unhold_packages:
-                cmd = ["apt-mark", "unhold"] + unhold_packages
-                expected_calls.append(
-                    mock.call(cmd, " ".join(cmd) + " failed.")
-                )
+        expected_calls = [
+            mock.call(["apt-mark", "showholds"], "apt-mark showholds failed.")
+        ]
+        if unhold_packages:
+            cmd = ["apt-mark", "unhold"] + unhold_packages
+            expected_calls.append(mock.call(cmd, " ".join(cmd) + " failed."))
         assert expected_calls == run_apt_command.call_args_list
         assert [mock.call(silent=False)] == setup_apt_config.call_args_list
 
@@ -1183,21 +1191,19 @@ class TestFipsEntitlementPackages:
         assert before == after
 
     @pytest.mark.parametrize(
-        "cfg_disable_fips_metapckage_override", ((True), (False))
-    )
-    @pytest.mark.parametrize(
-        "series", (("trusty"), ("xenial"), ("bionic"), ("focal"))
+        "cfg_disable_fips_metapckage_override", (True, False)
     )
+    @pytest.mark.parametrize("series", ("xenial", "bionic", "focal"))
     @pytest.mark.parametrize(
         "cloud_id",
         (
-            ("azure-china"),
-            ("aws-gov"),
-            ("aws-china"),
-            ("azure"),
-            ("aws"),
-            ("gce"),
-            (None),
+            "azure-china",
+            "aws-gov",
+            "aws-china",
+            "azure",
+            "aws",
+            "gce",
+            None,
         ),
     )
     @mock.patch("uaclient.util.is_config_value_true")
@@ -1287,3 +1293,35 @@ class TestFIPSUpdatesEntitlementEnable:
         else:
             assert not m_read_cache.call_count
             assert not m_write_cache.call_count
+
+
+class TestFIPSUpdatesEntitlementCanEnable:
+    @mock.patch("uaclient.util.is_config_value_true", return_value=False)
+    def test_can_enable_false_if_fips_enabled(
+        self, m_is_config_value_true, capsys, entitlement_factory
+    ):
+        """When entitlement is disabled, can_enable returns True."""
+        entitlement = entitlement_factory(FIPSUpdatesEntitlement)
+        with mock.patch.object(
+            entitlement,
+            "applicability_status",
+            return_value=(ApplicabilityStatus.APPLICABLE, ""),
+        ):
+            with mock.patch.object(
+                entitlement,
+                "application_status",
+                return_value=(ApplicationStatus.DISABLED, ""),
+            ):
+                with mock.patch(
+                    M_PATH + "FIPSEntitlement.application_status"
+                ) as m_fips_status:
+                    m_fips_status.return_value = (
+                        ApplicationStatus.ENABLED,
+                        None,
+                    )
+                    actual_ret, reason = entitlement.can_enable()
+                    assert actual_ret is False
+                    assert (
+                        reason.reason
+                        == CanEnableFailureReason.INCOMPATIBLE_SERVICE
+                    )
