@@ -4,7 +4,12 @@ from types import MappingProxyType
 import mock
 import pytest
 
-from uaclient import apt, exceptions, messages, status, util
+from uaclient import apt, exceptions, messages, util
+from uaclient.entitlements.entitlement_status import (
+    ApplicabilityStatus,
+    ApplicationStatus,
+    UserFacingStatus,
+)
 from uaclient.entitlements.repo import RepoEntitlement
 from uaclient.entitlements.tests.conftest import machine_token
 
@@ -60,18 +65,18 @@ class TestUserFacingStatus:
     ):
         """When applicability_status is INAPPLICABLE, return INAPPLICABLE."""
         platform_unsupported = copy.deepcopy(dict(PLATFORM_INFO_SUPPORTED))
-        platform_unsupported["series"] = "trusty"
-        platform_unsupported["version"] = "14.04 LTS (Trusty Tahr)"
+        platform_unsupported["series"] = "example"
+        platform_unsupported["version"] = "01.01 LTS (Example Version)"
         m_platform_info.return_value = platform_unsupported
         applicability, details = entitlement.applicability_status()
-        assert status.ApplicabilityStatus.INAPPLICABLE == applicability
+        assert ApplicabilityStatus.INAPPLICABLE == applicability
         expected_details = (
-            "Repo Test Class is not available for Ubuntu 14.04"
-            " LTS (Trusty Tahr)."
+            "Repo Test Class is not available for Ubuntu 01.01"
+            " LTS (Example Version)."
         )
         assert expected_details == details.msg
         uf_status, _ = entitlement.user_facing_status()
-        assert status.UserFacingStatus.INAPPLICABLE == uf_status
+        assert UserFacingStatus.INAPPLICABLE == uf_status
 
     @mock.patch(M_PATH + "util.get_platform_info")
     def test_unavailable_on_unentitled(self, m_platform_info, entitlement):
@@ -84,9 +89,9 @@ class TestUserFacingStatus:
         entitlement.cfg.write_cache("machine-token", no_entitlements)
         m_platform_info.return_value = dict(PLATFORM_INFO_SUPPORTED)
         applicability, _details = entitlement.applicability_status()
-        assert status.ApplicabilityStatus.APPLICABLE == applicability
+        assert ApplicabilityStatus.APPLICABLE == applicability
         uf_status, uf_details = entitlement.user_facing_status()
-        assert status.UserFacingStatus.UNAVAILABLE == uf_status
+        assert UserFacingStatus.UNAVAILABLE == uf_status
         assert "Repo Test Class is not entitled" == uf_details.msg
 
 
@@ -118,7 +123,7 @@ class TestProcessContractDeltas:
         entitled,
     ):
         """Disable the service on contract transitions to unentitled."""
-        application_status = status.ApplicationStatus.ENABLED
+        application_status = ApplicationStatus.ENABLED
         m_application_status.return_value = (application_status, "")
         assert entitlement.process_contract_deltas(
             {"entitlement": {"entitled": True}},
@@ -138,11 +143,11 @@ class TestProcessContractDeltas:
     ):
         """Noop when service is inactive and not enableByDefault."""
         m_application_status.return_value = (
-            status.ApplicationStatus.DISABLED,
+            ApplicationStatus.DISABLED,
             "",
         )
         m_applicability_status.return_value = (
-            status.ApplicabilityStatus.APPLICABLE,
+            ApplicabilityStatus.APPLICABLE,
             "",
         )
         assert not entitlement.process_contract_deltas(
@@ -166,11 +171,11 @@ class TestProcessContractDeltas:
     ):
         """Update apt when inactive, enableByDefault and allow_enable."""
         m_application_status.return_value = (
-            status.ApplicationStatus.DISABLED,
+            ApplicationStatus.DISABLED,
             "",
         )
         m_applicability_status.return_value = (
-            status.ApplicabilityStatus.APPLICABLE,
+            ApplicabilityStatus.APPLICABLE,
             "",
         )
         assert entitlement.process_contract_deltas(
@@ -196,11 +201,11 @@ class TestProcessContractDeltas:
     ):
         """Log a message when inactive, enableByDefault and allow_enable."""
         m_application_status.return_value = (
-            status.ApplicationStatus.DISABLED,
+            ApplicationStatus.DISABLED,
             "",
         )
         m_applicability_status.return_value = (
-            status.ApplicabilityStatus.APPLICABLE,
+            ApplicabilityStatus.APPLICABLE,
             "",
         )
         assert entitlement.process_contract_deltas(
@@ -237,7 +242,7 @@ class TestProcessContractDeltas:
     ):
         """Update_apt_config and packages if active and not enableByDefault."""
         m_check_apt_url_applied.return_value = False
-        application_status = status.ApplicationStatus.ENABLED
+        application_status = ApplicationStatus.ENABLED
         m_application_status.return_value = (application_status, "")
         deltas = {
             "entitlement": {"obligations": {"enableByDefault": False}},
@@ -266,9 +271,7 @@ class TestProcessContractDeltas:
         "uaclient.entitlements.base.UAEntitlement.process_contract_deltas"
     )
     @mock.patch("uaclient.config.UAConfig.read_cache")
-    @mock.patch(
-        M_PATH + "util.get_platform_info", return_value={"series": "trusty"}
-    )
+    @mock.patch(M_PATH + "util.get_platform_info")
     @mock.patch(M_PATH + "apt.remove_auth_apt_repo")
     @mock.patch.object(RepoTestEntitlement, "setup_apt_config")
     @mock.patch.object(RepoTestEntitlement, "remove_apt_config")
@@ -328,9 +331,7 @@ class TestProcessContractDeltas:
         "uaclient.entitlements.base.UAEntitlement.process_contract_deltas"
     )
     @mock.patch("uaclient.config.UAConfig.read_cache")
-    @mock.patch(
-        M_PATH + "util.get_platform_info", return_value={"series": "trusty"}
-    )
+    @mock.patch(M_PATH + "util.get_platform_info")
     @mock.patch(M_PATH + "apt.remove_auth_apt_repo")
     @mock.patch.object(RepoTestEntitlement, "setup_apt_config")
     @mock.patch.object(RepoTestEntitlement, "remove_apt_config")
@@ -385,23 +386,29 @@ class TestProcessContractDeltas:
 
 class TestRepoEnable:
     @pytest.mark.parametrize(
-        "pre_enable_msg, output, can_enable_call_count",
+        "pre_enable_msg, output, perform_enable_call_count",
         (
             (["msg1", (lambda: False, {}), "msg2"], "msg1\n", 0),
             (["msg1", (lambda: True, {}), "msg2"], "msg1\nmsg2\n", 1),
         ),
     )
+    @mock.patch.object(
+        RepoTestEntitlement,
+        "_perform_enable",
+        return_value=False,
+    )
     @mock.patch.object(
         RepoTestEntitlement,
         "can_enable",
-        return_value=(False, status.CanEnableFailure(None)),
+        return_value=(True, None),
     )
     def test_enable_can_exit_on_pre_enable_messaging_hooks(
         self,
-        m_can_enable,
+        _m_can_enable,
+        m_perform_enable,
         pre_enable_msg,
         output,
-        can_enable_call_count,
+        perform_enable_call_count,
         entitlement,
         capsys,
     ):
@@ -414,7 +421,7 @@ class TestRepoEnable:
                 entitlement.enable()
         stdout, _ = capsys.readouterr()
         assert output == stdout
-        assert can_enable_call_count == m_can_enable.call_count
+        assert perform_enable_call_count == m_perform_enable.call_count
 
     @pytest.mark.parametrize(
         "pre_disable_msg,post_disable_msg,output,retval",
@@ -734,8 +741,10 @@ class TestRemoveAptConfig:
     @mock.patch(M_PATH + "apt.remove_apt_list_files")
     @mock.patch(M_PATH + "apt.run_apt_command")
     @mock.patch(M_PATH + "util.get_platform_info")
+    @mock.patch(M_PATH + "util.apply_contract_overrides")
     def test_repo_pin_priority_int_removes_apt_preferences(
         self,
+        _m_contract_overrides,
         m_get_platform,
         _m_run_apt_command,
         _m_remove_apt_list_files,
@@ -856,14 +865,16 @@ class TestSetupAptConfig:
         """Calls apt.setup_apt_proxy()"""
         entitlement.setup_apt_config()
         assert [
-            mock.call(http_proxy=None, https_proxy=None)
+            mock.call(http_proxy=None, https_proxy=None, proxy_scope=None)
         ] == m_setup_apt_proxy.call_args_list
 
     @mock.patch("uaclient.apt.setup_apt_proxy")
     @mock.patch(M_PATH + "apt.add_auth_apt_repo")
     @mock.patch(M_PATH + "apt.run_apt_install_command")
+    @mock.patch(M_PATH + "util.apply_contract_overrides")
     def test_install_prerequisite_packages(
         self,
+        _m_contract_overrides,
         m_run_apt_install_command,
         m_add_auth_repo,
         _m_setup_apt_proxy,
@@ -908,8 +919,10 @@ class TestSetupAptConfig:
     @mock.patch(M_PATH + "apt.add_auth_apt_repo")
     @mock.patch(M_PATH + "apt.run_apt_command")
     @mock.patch(M_PATH + "util.get_platform_info")
+    @mock.patch(M_PATH + "util.apply_contract_overrides")
     def test_setup_with_repo_pin_priority_never_removes_apt_preferences_file(
         self,
+        _m_contract_overrides,
         m_get_platform_info,
         m_run_apt_command,
         m_add_auth_repo,
@@ -940,8 +953,10 @@ class TestSetupAptConfig:
     @mock.patch(M_PATH + "apt.run_apt_update_command")
     @mock.patch(M_PATH + "apt.add_ppa_pinning")
     @mock.patch(M_PATH + "util.get_platform_info")
+    @mock.patch(M_PATH + "util.apply_contract_overrides")
     def test_setup_with_repo_pin_priority_int_adds_a_pins_repo_apt_preference(
         self,
+        _m_apply_overrides,
         m_get_platform_info,
         m_add_ppa_pinning,
         m_run_apt_update_command,
@@ -1009,7 +1024,7 @@ class TestApplicationStatus:
 
         application_status, explanation = entitlement.application_status()
 
-        assert status.ApplicationStatus.DISABLED == application_status
+        assert ApplicationStatus.DISABLED == application_status
         assert (
             "Repo Test Class does not have an aptURL directive"
             == explanation.msg
@@ -1023,9 +1038,9 @@ class TestApplicationStatus:
             (500, "https://esm.ubuntu.com/ubuntu", True),
         ),
     )
-    @mock.patch(M_PATH + "apt.run_apt_command")
+    @mock.patch(M_PATH + "apt.run_apt_cache_policy_command")
     def test_enabled_status_by_apt_policy(
-        self, m_run_apt_command, pin, policy_url, enabled, entitlement_factory
+        self, m_run_apt_policy, pin, policy_url, enabled, entitlement_factory
     ):
         """Report ENABLED when apt-policy lists specific aptURL and 500 pin."""
         entitlement = entitlement_factory(
@@ -1040,15 +1055,15 @@ class TestApplicationStatus:
             " release v=18.04,o=UbuntuESMApps,...,n=bionic,l=UbuntuESMApps",
             "  origin esm.ubuntu.com",
         ]
-        m_run_apt_command.return_value = "\n".join(policy_lines)
+        m_run_apt_policy.return_value = "\n".join(policy_lines)
 
         application_status, explanation = entitlement.application_status()
 
         if enabled:
-            expected_status = status.ApplicationStatus.ENABLED
+            expected_status = ApplicationStatus.ENABLED
             expected_explanation = "Repo Test Class is active"
         else:
-            expected_status = status.ApplicationStatus.DISABLED
+            expected_status = ApplicationStatus.DISABLED
             expected_explanation = "Repo Test Class is not configured"
         assert expected_status == application_status
         assert expected_explanation == explanation.msg
