@@ -12,8 +12,8 @@ import pytest
 from uaclient import apt, exceptions, messages, util
 from uaclient.apt import (
     APT_AUTH_COMMENT,
-    APT_CONFIG_PROXY_HTTP,
-    APT_CONFIG_PROXY_HTTPS,
+    APT_CONFIG_GLOBAL_PROXY_HTTP,
+    APT_CONFIG_GLOBAL_PROXY_HTTPS,
     APT_KEYS_DIR,
     APT_PROXY_CONF_FILE,
     APT_RETRIES,
@@ -28,6 +28,7 @@ from uaclient.apt import (
     remove_apt_list_files,
     remove_auth_apt_repo,
     remove_repo_from_apt_auth_file,
+    run_apt_cache_policy_command,
     run_apt_update_command,
     setup_apt_proxy,
 )
@@ -167,7 +168,7 @@ class TestValidAptCredentials:
             ),
             (
                 100,
-                "E: Failed to fetch ... HttpError401 on trusty",
+                "E: Failed to fetch ... HttpError401 on xenial",
                 "Invalid APT credentials provided for http://fakerepo",
             ),
             (
@@ -916,6 +917,45 @@ class TestRunAptCommand:
         expected_message = "\n".join(output_list) + "."
         assert expected_message == excinfo.value.msg
 
+    @mock.patch("uaclient.apt.util.subp")
+    def test_run_update_command_clean_apt_cache_policy_cache(self, m_subp):
+        m_subp.side_effect = [
+            ("policy1", ""),
+            ("update", ""),
+            ("policy2", ""),
+        ]
+
+        assert "policy1" == run_apt_cache_policy_command()
+        # Confirming that caching is happening
+        assert "policy1" == run_apt_cache_policy_command()
+
+        run_apt_update_command()
+
+        # Confirm cache was cleared
+        assert "policy2" == run_apt_cache_policy_command()
+        run_apt_cache_policy_command.cache_clear()
+
+    @mock.patch("uaclient.apt.util.subp")
+    def test_failed_run_update_command_clean_apt_cache_policy_cache(
+        self, m_subp
+    ):
+        m_subp.side_effect = [
+            ("policy1", ""),
+            exceptions.UserFacingError("test"),
+            ("policy2", ""),
+        ]
+
+        assert "policy1" == run_apt_cache_policy_command()
+        # Confirming that caching is happening
+        assert "policy1" == run_apt_cache_policy_command()
+
+        with pytest.raises(exceptions.UserFacingError):
+            run_apt_update_command()
+
+        # Confirm cache was cleared
+        assert "policy2" == run_apt_cache_policy_command()
+        run_apt_cache_policy_command.cache_clear()
+
 
 class TestAptProxyConfig:
     @pytest.mark.parametrize(
@@ -929,12 +969,12 @@ class TestAptProxyConfig:
                     mock.call(
                         APT_PROXY_CONF_FILE,
                         messages.APT_PROXY_CONFIG_HEADER
-                        + APT_CONFIG_PROXY_HTTP.format(
+                        + APT_CONFIG_GLOBAL_PROXY_HTTP.format(
                             proxy_url="mock_http_proxy"
                         ),
                     )
                 ],
-                messages.SETTING_SERVICE_PROXY.format(service="APT"),
+                messages.SETTING_SERVICE_PROXY_SCOPE.format(scope="global"),
             ),
             (
                 {"https_proxy": "mock_https_proxy"},
@@ -943,12 +983,12 @@ class TestAptProxyConfig:
                     mock.call(
                         APT_PROXY_CONF_FILE,
                         messages.APT_PROXY_CONFIG_HEADER
-                        + APT_CONFIG_PROXY_HTTPS.format(
+                        + APT_CONFIG_GLOBAL_PROXY_HTTPS.format(
                             proxy_url="mock_https_proxy"
                         ),
                     )
                 ],
-                messages.SETTING_SERVICE_PROXY.format(service="APT"),
+                messages.SETTING_SERVICE_PROXY_SCOPE.format(scope="global"),
             ),
             (
                 {
@@ -960,15 +1000,15 @@ class TestAptProxyConfig:
                     mock.call(
                         APT_PROXY_CONF_FILE,
                         messages.APT_PROXY_CONFIG_HEADER
-                        + APT_CONFIG_PROXY_HTTP.format(
+                        + APT_CONFIG_GLOBAL_PROXY_HTTP.format(
                             proxy_url="mock_http_proxy"
                         )
-                        + APT_CONFIG_PROXY_HTTPS.format(
+                        + APT_CONFIG_GLOBAL_PROXY_HTTPS.format(
                             proxy_url="mock_https_proxy"
                         ),
                     )
                 ],
-                messages.SETTING_SERVICE_PROXY.format(service="APT"),
+                messages.SETTING_SERVICE_PROXY_SCOPE.format(scope="global"),
             ),
         ],
     )
