@@ -90,11 +90,12 @@ Client to manage Ubuntu Advantage services on a machine.
 
 
 @pytest.fixture(params=["direct", "--help", "ua help", "ua help --all"])
-def get_help(request, capsys):
+def get_help(request, capsys, FakeConfig):
+    cfg = FakeConfig()
     if request.param == "direct":
 
         def _get_help_output():
-            parser = get_parser()
+            parser = get_parser(cfg)
             help_file = io.StringIO()
             parser.print_help(file=help_file)
             return (help_file.getvalue(), "base")
@@ -102,7 +103,7 @@ def get_help(request, capsys):
     elif request.param == "--help":
 
         def _get_help_output():
-            parser = get_parser()
+            parser = get_parser(cfg)
             with mock.patch("sys.argv", ["ua", "--help"]):
                 with pytest.raises(SystemExit):
                     parser.parse_args()
@@ -177,7 +178,7 @@ class TestCLIParser:
             ("json", {"name": "test", "available": "yes", "help": "Test"}),
         ),
     )
-    @mock.patch("uaclient.contract.get_available_resources")
+    @mock.patch("uaclient.status.get_available_resources")
     @mock.patch(
         "uaclient.config.UAConfig.is_attached", new_callable=mock.PropertyMock
     )
@@ -206,7 +207,7 @@ class TestCLIParser:
 
         fake_stdout = io.StringIO()
         with mock.patch(
-            "uaclient.entitlements.entitlement_factory",
+            "uaclient.status.entitlement_factory",
             return_value=m_entitlement_cls,
         ):
             with contextlib.redirect_stdout(fake_stdout):
@@ -231,7 +232,7 @@ class TestCLIParser:
         ),
     )
     @pytest.mark.parametrize("is_beta", (True, False))
-    @mock.patch("uaclient.contract.get_available_resources")
+    @mock.patch("uaclient.status.get_available_resources")
     @mock.patch(
         "uaclient.config.UAConfig.is_attached", new_callable=mock.PropertyMock
     )
@@ -291,7 +292,7 @@ class TestCLIParser:
 
         fake_stdout = io.StringIO()
         with mock.patch(
-            "uaclient.entitlements.entitlement_factory",
+            "uaclient.status.entitlement_factory",
             return_value=m_entitlement_cls,
         ):
             with contextlib.redirect_stdout(fake_stdout):
@@ -310,7 +311,7 @@ class TestCLIParser:
             ufs_call_count == m_entitlement_obj.user_facing_status.call_count
         )
 
-    @mock.patch("uaclient.contract.get_available_resources")
+    @mock.patch("uaclient.status.get_available_resources")
     def test_help_command_for_invalid_service(self, m_available_resources):
         """Test help command when an invalid service is provided."""
         m_args = mock.MagicMock()
@@ -668,8 +669,11 @@ class TestMain:
         assert "NOT_UA_ENV=YES" not in log
 
     @mock.patch("uaclient.cli.contract.get_available_resources")
-    def test_argparse_errors_well_formatted(self, _m_resources, capsys):
-        parser = get_parser()
+    def test_argparse_errors_well_formatted(
+        self, _m_resources, capsys, FakeConfig
+    ):
+        cfg = FakeConfig()
+        parser = get_parser(cfg)
         with mock.patch("sys.argv", ["ua", "enable"]):
             with pytest.raises(SystemExit) as excinfo:
                 parser.parse_args()
@@ -855,13 +859,13 @@ class TestGetValidEntitlementNames:
         "uaclient.cli.entitlements.valid_services",
         return_value=["ent1", "ent2", "ent3"],
     )
-    def test_get_valid_entitlements(self, _m_valid_services):
+    def test_get_valid_entitlements(self, _m_valid_services, FakeConfig):
         service = ["ent1", "ent3", "ent4"]
         expected_ents_found = ["ent1", "ent3"]
         expected_ents_not_found = ["ent4"]
 
         actual_ents_found, actual_ents_not_found = get_valid_entitlement_names(
-            service
+            service, cfg=FakeConfig()
         )
 
         assert expected_ents_found == actual_ents_found
