@@ -7,7 +7,7 @@ import mock
 import pytest
 import yaml
 
-from uaclient import event_logger, messages
+from uaclient import event_logger, messages, status
 from uaclient.cli import (
     UA_AUTH_TOKEN_URL,
     action_attach,
@@ -43,7 +43,7 @@ BASIC_MACHINE_TOKEN = {
     },
 }
 
-ENTITLED_TRUSTY_ESM_RESOURCE = {
+ENTITLED_EXAMPLE_ESM_RESOURCE = {
     "obligations": {"enableByDefault": True},
     "type": "esm-infra",
     "directives": {
@@ -59,12 +59,12 @@ ENTITLED_TRUSTY_ESM_RESOURCE = {
             "s390x",
             "x86_64",
         ],
-        "series": ["precise", "trusty", "xenial", "bionic"],
+        "series": ["series-example-1", "series-example-2", "series-example-3"],
     },
     "series": {
-        "trusty": {
+        "series-example-1": {
             "directives": {
-                "suites": ["trusty-infra-security", "trusty-infra-updates"]
+                "suites": ["example-infra-security", "example-infra-updates"]
             }
         }
     },
@@ -74,7 +74,7 @@ ENTITLED_TRUSTY_ESM_RESOURCE = {
 ENTITLED_MACHINE_TOKEN = copy.deepcopy(BASIC_MACHINE_TOKEN)
 ENTITLED_MACHINE_TOKEN["machineTokenInfo"]["contractInfo"][
     "resourceEntitlements"
-] = [ENTITLED_TRUSTY_ESM_RESOURCE]
+] = [ENTITLED_EXAMPLE_ESM_RESOURCE]
 
 
 @mock.patch(M_PATH + "os.getuid")
@@ -244,7 +244,7 @@ class TestActionAttach:
     )
     @mock.patch("uaclient.util.should_reboot", return_value=False)
     @mock.patch("uaclient.config.UAConfig.remove_notice")
-    @mock.patch("uaclient.contract.get_available_resources")
+    @mock.patch("uaclient.status.get_available_resources")
     @mock.patch("uaclient.jobs.update_messaging.update_apt_and_motd_messages")
     @mock.patch(M_PATH + "contract.request_updated_contract")
     def test_status_updated_when_auto_enable_fails(
@@ -264,7 +264,7 @@ class TestActionAttach:
         token = "contract-token"
         args = mock.MagicMock(token=token, attach_config=None)
         cfg = FakeConfig()
-        cfg.status()  # persist unattached status
+        status.status(cfg=cfg)  # persist unattached status
         # read persisted status cache from disk
         orig_unattached_status = cfg.read_cache("status-cache")
 
@@ -273,8 +273,10 @@ class TestActionAttach:
             raise error_class(error_str)
 
         request_updated_contract.side_effect = fake_request_updated_contract
-        ret = action_attach(args, cfg=cfg)
-        assert 1 == ret
+        with pytest.raises(SystemExit) as excinfo:
+            main_error_handler(action_attach)(args, cfg)
+
+        assert 1 == excinfo.value.code
         assert cfg.is_attached
         # Assert updated status cache is written to disk
         assert orig_unattached_status != cfg.read_cache(
@@ -358,7 +360,7 @@ class TestActionAttach:
     @pytest.mark.parametrize("auto_enable", (True, False))
     @mock.patch("uaclient.util.should_reboot", return_value=False)
     @mock.patch("uaclient.config.UAConfig.remove_notice")
-    @mock.patch("uaclient.contract.get_available_resources")
+    @mock.patch("uaclient.status.get_available_resources")
     @mock.patch("uaclient.jobs.update_messaging.update_apt_and_motd_messages")
     def test_auto_enable_passed_through_to_request_updated_contract(
         self,
@@ -472,10 +474,10 @@ class TestActionAttach:
     @mock.patch("uaclient.util.handle_unicode_characters")
     @mock.patch("uaclient.status.format_tabular")
     @mock.patch(M_PATH + "actions.status")
-    @mock.patch("uaclient.jobs.disable_license_check_if_applicable")
+    @mock.patch("uaclient.daemon.stop")
     def test_attach_config_enable_services(
         self,
-        _m_disable_license_job,
+        _m_daemon_stop,
         m_status,
         m_format_tabular,
         m_handle_unicode,
@@ -532,14 +534,14 @@ class TestActionAttach:
         assert expected == json.loads(fake_stdout.getvalue())
 
     @mock.patch("uaclient.contract.process_entitlement_delta")
-    @mock.patch("uaclient.util.apply_series_overrides")
+    @mock.patch("uaclient.util.apply_contract_overrides")
     @mock.patch("uaclient.contract.UAContractClient.request_url")
     @mock.patch("uaclient.jobs.update_messaging.update_apt_and_motd_messages")
     def test_attach_when_one_service_fails_to_enable(
         self,
         _m_update_messages,
         m_request_url,
-        _m_apply_series_overrides,
+        _m_apply_contract_overrides,
         m_process_entitlement_delta,
         _m_getuid,
         FakeConfig,
@@ -583,11 +585,14 @@ class TestActionAttach:
         )
 
         fake_stdout = io.StringIO()
-        with contextlib.redirect_stdout(fake_stdout):
-            with mock.patch.object(
-                event, "_event_logger_mode", event_logger.EventLoggerMode.JSON
-            ):
-                main_error_handler(action_attach)(args, cfg)
+        with pytest.raises(SystemExit):
+            with contextlib.redirect_stdout(fake_stdout):
+                with mock.patch.object(
+                    event,
+                    "_event_logger_mode",
+                    event_logger.EventLoggerMode.JSON,
+                ):
+                    main_error_handler(action_attach)(args, cfg)
 
         expected_msg = messages.ATTACH_FAILURE_DEFAULT_SERVICES
         expected = {
@@ -623,53 +628,59 @@ class TestParser:
         parser = attach_parser(mock.Mock())
         assert "Flags" == parser._optionals.title
 
-    def test_attach_parser_stores_token(self, _m_resources):
-        full_parser = get_parser()
+    def test_attach_parser_stores_token(self, _m_resources, FakeConfig):
+        full_parser = get_parser(FakeConfig())
         with mock.patch("sys.argv", ["ua", "attach", "token"]):
             args = full_parser.parse_args()
         assert "token" == args.token
 
-    def test_attach_parser_allows_empty_required_token(self, _m_resources):
+    def test_attach_parser_allows_empty_required_token(
+        self, _m_resources, FakeConfig
+    ):
         """Token required but parse_args allows none due to action_attach"""
-        full_parser = get_parser()
+        full_parser = get_parser(FakeConfig())
         with mock.patch("sys.argv", ["ua", "attach"]):
             args = full_parser.parse_args()
         assert None is args.token
 
     def test_attach_parser_help_points_to_ua_contract_dashboard_url(
-        self, _m_resources, capsys
+        self, _m_resources, capsys, FakeConfig
     ):
         """Contracts' dashboard URL is referenced by ua attach --help."""
-        full_parser = get_parser()
+        full_parser = get_parser(FakeConfig())
         with mock.patch("sys.argv", ["ua", "attach", "--help"]):
             with pytest.raises(SystemExit):
                 full_parser.parse_args()
         assert UA_AUTH_TOKEN_URL in capsys.readouterr()[0]
 
     def test_attach_parser_accepts_and_stores_no_auto_enable(
-        self, _m_resources
+        self, _m_resources, FakeConfig
     ):
-        full_parser = get_parser()
+        full_parser = get_parser(FakeConfig())
         with mock.patch(
             "sys.argv", ["ua", "attach", "--no-auto-enable", "token"]
         ):
             args = full_parser.parse_args()
         assert not args.auto_enable
 
-    def test_attach_parser_defaults_to_auto_enable(self, _m_resources):
-        full_parser = get_parser()
+    def test_attach_parser_defaults_to_auto_enable(
+        self, _m_resources, FakeConfig
+    ):
+        full_parser = get_parser(FakeConfig())
         with mock.patch("sys.argv", ["ua", "attach", "token"]):
             args = full_parser.parse_args()
         assert args.auto_enable
 
-    def test_attach_parser_default_to_cli_format(self, _m_resources):
-        full_parser = get_parser()
+    def test_attach_parser_default_to_cli_format(
+        self, _m_resources, FakeConfig
+    ):
+        full_parser = get_parser(FakeConfig())
         with mock.patch("sys.argv", ["ua", "attach", "token"]):
             args = full_parser.parse_args()
         assert "cli" == args.format
 
-    def test_attach_parser_accepts_format_flag(self, _m_resources):
-        full_parser = get_parser()
+    def test_attach_parser_accepts_format_flag(self, _m_resources, FakeConfig):
+        full_parser = get_parser(FakeConfig())
         with mock.patch(
             "sys.argv", ["ua", "attach", "token", "--format", "json"]
         ):
