@@ -6,8 +6,12 @@ import textwrap
 import mock
 import pytest
 
-from uaclient import entitlements, event_logger, exceptions, messages, status
+from uaclient import entitlements, event_logger, exceptions, messages
 from uaclient.cli import action_enable, main, main_error_handler
+from uaclient.entitlements.entitlement_status import (
+    CanEnableFailure,
+    CanEnableFailureReason,
+)
 
 HELP_OUTPUT = textwrap.dedent(
     """\
@@ -153,7 +157,7 @@ class TestActionEnable:
     @pytest.mark.parametrize(
         "uid,expected_error_template",
         [
-            (0, messages.ENABLE_FAILURE_UNATTACHED),
+            (0, messages.VALID_SERVICE_FAILURE_UNATTACHED),
             (1000, messages.NONROOT_USER),
         ],
     )
@@ -173,10 +177,13 @@ class TestActionEnable:
 
         cfg = FakeConfig()
         args = mock.MagicMock()
+        args.command = "enable"
         args.service = ["esm-infra"]
 
         if not uid:
-            expected_error = expected_error_template.format(name="esm-infra")
+            expected_error = expected_error_template.format(
+                valid_service="esm-infra"
+            )
         else:
             expected_error = expected_error_template
 
@@ -208,6 +215,7 @@ class TestActionEnable:
         }
         assert expected == json.loads(capsys.readouterr()[0])
 
+    @pytest.mark.parametrize("is_attached", (True, False))
     @pytest.mark.parametrize(
         "uid,expected_error_template",
         [
@@ -221,34 +229,46 @@ class TestActionEnable:
         m_getuid,
         uid,
         expected_error_template,
+        is_attached,
         event,
         FakeConfig,
     ):
         """Check invalid service name results in custom error message."""
 
         m_getuid.return_value = uid
-        cfg = FakeConfig.for_attached_machine()
+        if is_attached:
+            cfg = FakeConfig.for_attached_machine()
+            service_msg = "\n".join(
+                textwrap.wrap(
+                    (
+                        "Try "
+                        + ", ".join(
+                            entitlements.valid_services(
+                                cfg=cfg, allow_beta=True
+                            )
+                        )
+                        + "."
+                    ),
+                    width=80,
+                    break_long_words=False,
+                    break_on_hyphens=False,
+                )
+            )
+        else:
+            cfg = FakeConfig()
+            service_msg = "See https://ubuntu.com/advantage"
+
         args = mock.MagicMock()
         args.service = ["bogus"]
+        args.command = "enable"
         with pytest.raises(exceptions.UserFacingError) as err:
             action_enable(args, cfg)
 
-        service_msg = "\n".join(
-            textwrap.wrap(
-                (
-                    "Try "
-                    + ", ".join(entitlements.valid_services(allow_beta=True))
-                    + "."
-                ),
-                width=80,
-                break_long_words=False,
-                break_on_hyphens=False,
-            )
-        )
-
         if not uid:
             expected_error = expected_error_template.format(
-                operation="enable", name="bogus", service_msg=service_msg
+                operation="enable",
+                invalid_service="bogus",
+                service_msg=service_msg,
             )
         else:
             expected_error = expected_error_template
@@ -274,7 +294,72 @@ class TestActionEnable:
                     "type": "system",
                 }
             ],
-            "failed_services": ["bogus"] if not uid else [],
+            "failed_services": ["bogus"] if not uid and is_attached else [],
+            "needs_reboot": False,
+            "processed_services": [],
+            "warnings": [],
+        }
+        assert expected == json.loads(fake_stdout.getvalue())
+
+    @pytest.mark.parametrize(
+        "uid,expected_error_template",
+        [
+            (0, messages.MIXED_SERVICES_FAILURE_UNATTACHED),
+            (1000, messages.NONROOT_USER),
+        ],
+    )
+    def test_unattached_invalid_and_valid_service_error_message(
+        self,
+        _request_updated_contract,
+        m_getuid,
+        uid,
+        expected_error_template,
+        event,
+        FakeConfig,
+    ):
+        """Check invalid service name results in custom error message."""
+
+        m_getuid.return_value = uid
+        cfg = FakeConfig()
+
+        args = mock.MagicMock()
+        args.service = ["bogus", "fips"]
+        args.command = "enable"
+        with pytest.raises(exceptions.UserFacingError) as err:
+            action_enable(args, cfg)
+
+        if not uid:
+            expected_error = expected_error_template.format(
+                operation="enable",
+                valid_service="fips",
+                invalid_service="bogus",
+                service_msg="",
+            )
+        else:
+            expected_error = expected_error_template
+
+        assert expected_error.msg == err.value.msg
+
+        with pytest.raises(SystemExit):
+            with mock.patch.object(
+                event, "_event_logger_mode", event_logger.EventLoggerMode.JSON
+            ):
+                fake_stdout = io.StringIO()
+                with contextlib.redirect_stdout(fake_stdout):
+                    main_error_handler(action_enable)(args, cfg)
+
+        expected = {
+            "_schema_version": event_logger.JSON_SCHEMA_VERSION,
+            "result": "failure",
+            "errors": [
+                {
+                    "message": expected_error.msg,
+                    "message_code": expected_error.name,
+                    "service": None,
+                    "type": "system",
+                }
+            ],
+            "failed_services": [],
             "needs_reboot": False,
             "processed_services": [],
             "warnings": [],
@@ -282,7 +367,7 @@ class TestActionEnable:
         assert expected == json.loads(fake_stdout.getvalue())
 
     @pytest.mark.parametrize("assume_yes", (True, False))
-    @mock.patch("uaclient.contract.get_available_resources", return_value={})
+    @mock.patch("uaclient.status.get_available_resources", return_value={})
     @mock.patch("uaclient.entitlements.valid_services")
     def test_assume_yes_passed_to_service_init(
         self,
@@ -322,7 +407,7 @@ class TestActionEnable:
             )
         ] == m_entitlement_cls.call_args_list
 
-    @mock.patch("uaclient.contract.get_available_resources", return_value={})
+    @mock.patch("uaclient.status.get_available_resources", return_value={})
     @mock.patch("uaclient.entitlements.entitlement_factory")
     @mock.patch("uaclient.entitlements.valid_services")
     def test_entitlements_not_found_disabled_and_enabled(
@@ -349,7 +434,7 @@ class TestActionEnable:
         m_ent2_obj = m_ent2_cls.return_value
         m_ent2_obj.enable.return_value = (
             False,
-            status.CanEnableFailure(status.CanEnableFailureReason.IS_BETA),
+            CanEnableFailure(CanEnableFailureReason.IS_BETA),
         )
 
         m_ent3_cls = mock.Mock()
@@ -359,7 +444,7 @@ class TestActionEnable:
         m_ent3_obj = m_ent3_cls.return_value
         m_ent3_obj.enable.return_value = (True, None)
 
-        def factory_side_effect(name, not_found_okay=True):
+        def factory_side_effect(cfg, name, not_found_okay=True):
             if name == "ent2":
                 return m_ent2_cls
             if name == "ent3":
@@ -385,7 +470,7 @@ class TestActionEnable:
 
         expected_error = expected_error_tmpl.format(
             operation="enable",
-            name="ent1, ent2",
+            invalid_service="ent1, ent2",
             service_msg=(
                 "Try "
                 + ", ".join(entitlements.valid_services(allow_beta=False))
@@ -439,7 +524,7 @@ class TestActionEnable:
         assert expected == json.loads(fake_stdout.getvalue())
 
     @pytest.mark.parametrize("beta_flag", ((False), (True)))
-    @mock.patch("uaclient.contract.get_available_resources", return_value={})
+    @mock.patch("uaclient.status.get_available_resources", return_value={})
     @mock.patch("uaclient.entitlements.entitlement_factory")
     @mock.patch("uaclient.entitlements.valid_services")
     def test_entitlements_not_found_and_beta(
@@ -465,9 +550,7 @@ class TestActionEnable:
         m_ent2_is_beta = mock.PropertyMock(return_value=True)
         type(m_ent2_cls)._is_beta = m_ent2_is_beta
         m_ent2_obj = m_ent2_cls.return_value
-        failure_reason = status.CanEnableFailure(
-            status.CanEnableFailureReason.IS_BETA
-        )
+        failure_reason = CanEnableFailure(CanEnableFailureReason.IS_BETA)
         if beta_flag:
             m_ent2_obj.enable.return_value = (True, None)
         else:
@@ -487,7 +570,7 @@ class TestActionEnable:
         args_mock.assume_yes = assume_yes
         args_mock.beta = beta_flag
 
-        def factory_side_effect(name, not_found_okay=True):
+        def factory_side_effect(cfg, name, not_found_okay=True):
             if name == "ent2":
                 return m_ent2_cls
             if name == "ent3":
@@ -496,7 +579,7 @@ class TestActionEnable:
 
         m_entitlement_factory.side_effect = factory_side_effect
 
-        def valid_services_side_effect(allow_beta, all_names=False):
+        def valid_services_side_effect(cfg, allow_beta, all_names=False):
             if allow_beta:
                 return ["ent2", "ent3"]
             return ["ent2"]
@@ -508,7 +591,7 @@ class TestActionEnable:
         mock_ent_list = [m_ent3_cls]
         mock_obj_list = [m_ent3_obj]
 
-        service_names = entitlements.valid_services(allow_beta=beta_flag)
+        service_names = entitlements.valid_services(cfg, allow_beta=beta_flag)
         ent_str = "Try " + ", ".join(service_names) + "."
         if not beta_flag:
             not_found_name += ", ent2"
@@ -530,7 +613,9 @@ class TestActionEnable:
                 action_enable(args_mock, cfg)
 
         expected_error = expected_error_tmpl.format(
-            operation="enable", name=not_found_name, service_msg=service_msg
+            operation="enable",
+            invalid_service=not_found_name,
+            service_msg=service_msg,
         )
         assert expected_error.msg == err.value.msg
         assert expected_msg == fake_stdout.getvalue()
@@ -582,7 +667,7 @@ class TestActionEnable:
         }
         assert expected == json.loads(fake_stdout.getvalue())
 
-    @mock.patch("uaclient.contract.get_available_resources", return_value={})
+    @mock.patch("uaclient.status.get_available_resources", return_value={})
     def test_print_message_when_can_enable_fails(
         self,
         _m_get_available_resources,
@@ -597,8 +682,8 @@ class TestActionEnable:
         m_entitlement_obj = m_entitlement_cls.return_value
         m_entitlement_obj.enable.return_value = (
             False,
-            status.CanEnableFailure(
-                status.CanEnableFailureReason.ALREADY_ENABLED,
+            CanEnableFailure(
+                CanEnableFailureReason.ALREADY_ENABLED,
                 message=messages.NamedMessage("test-code", "msg"),
             ),
         )
@@ -685,7 +770,7 @@ class TestActionEnable:
 
         assert expected_msg == fake_stdout.getvalue()
 
-        service_names = entitlements.valid_services(allow_beta=beta)
+        service_names = entitlements.valid_services(cfg=cfg, allow_beta=beta)
         ent_str = "Try " + ", ".join(service_names) + "."
         service_msg = "\n".join(
             textwrap.wrap(
@@ -697,7 +782,7 @@ class TestActionEnable:
         )
         expected_error = expected_error_tmpl.format(
             operation="enable",
-            name=", ".join(sorted(service)),
+            invalid_service=", ".join(sorted(service)),
             service_msg=service_msg,
         )
         assert expected_error.msg == err.value.msg
@@ -729,9 +814,11 @@ class TestActionEnable:
         assert expected == json.loads(fake_stdout.getvalue())
 
     @pytest.mark.parametrize("allow_beta", ((True), (False)))
-    @mock.patch("uaclient.contract.get_available_resources", return_value={})
+    @mock.patch("uaclient.status.get_available_resources", return_value={})
+    @mock.patch("uaclient.status.status")
     def test_entitlement_instantiated_and_enabled(
         self,
+        m_status,
         _m_get_available_resources,
         _m_request_updated_contract,
         m_getuid,
@@ -745,7 +832,6 @@ class TestActionEnable:
         m_entitlement_obj.enable.return_value = (True, None)
 
         cfg = FakeConfig.for_attached_machine()
-        cfg.status = mock.Mock()
 
         args_mock = mock.MagicMock()
         args_mock.assume_yes = False
@@ -775,7 +861,7 @@ class TestActionEnable:
         expected_ret = 0
         assert [expected_enable_call] == m_entitlement.enable.call_args_list
         assert expected_ret == ret
-        assert 1 == cfg.status.call_count
+        assert 1 == m_status.call_count
 
         with mock.patch(
             "uaclient.entitlements.entitlement_factory",
