@@ -14,6 +14,7 @@ import yaml
 from uaclient import exceptions, messages, status, version
 from uaclient.cli import action_status, get_parser, main, status_parser
 from uaclient.event_logger import EventLoggerMode
+from uaclient.tests.test_cli import M_PATH_UACONFIG
 
 M_PATH = "uaclient.cli."
 
@@ -24,6 +25,7 @@ RESPONSE_AVAILABLE_SERVICES = [
     {"name": "esm-infra", "available": False},
     {"name": "esm-apps", "available": True},
     {"name": "fips-updates", "available": False},
+    {"name": "realtime-kernel", "available": False},
     {"name": "ros", "available": False},
     {"name": "ros-updates", "available": False},
 ]
@@ -68,41 +70,34 @@ RESPONSE_CONTRACT_INFO = {
 }
 
 SIMULATED_STATUS = """\
-SERVICE       AVAILABLE  ENTITLED   AUTO_ENABLED  DESCRIPTION
-esm-infra     no         yes        yes           UA Infra: Extended Security\
- Maintenance (ESM)
-fips          no         no         no            NIST-certified core packages
-fips-updates  no         no         no            NIST-certified core packages\
- with priority security updates
-livepatch     yes        yes        no            Canonical Livepatch service
-"""
+SERVICE          AVAILABLE  ENTITLED   AUTO_ENABLED  DESCRIPTION
+esm-infra        no         yes        yes           UA Infra: Extended Security Maintenance (ESM)
+fips             no         no         no            NIST-certified core packages
+fips-updates     no         no         no            NIST-certified core packages with priority security updates
+livepatch        yes        yes        no            Canonical Livepatch service
+"""  # noqa: E501
 
 UNATTACHED_STATUS = """\
-SERVICE       AVAILABLE  DESCRIPTION
-esm-infra     no         UA Infra: Extended Security Maintenance (ESM)
-fips          no         NIST-certified core packages
-fips-updates  no         NIST-certified core packages with priority\
- security updates
-livepatch     yes        Canonical Livepatch service
+SERVICE          AVAILABLE  DESCRIPTION
+esm-infra        no         UA Infra: Extended Security Maintenance (ESM)
+fips             no         NIST-certified core packages
+fips-updates     no         NIST-certified core packages with priority security updates
+livepatch        yes        Canonical Livepatch service
 
 This machine is not attached to a UA subscription.
 See https://ubuntu.com/advantage
-"""
+"""  # noqa: E501
 
 ATTACHED_STATUS = """\
-SERVICE       ENTITLED  STATUS    DESCRIPTION
-esm-apps      no        {dash}         UA Apps: Extended Security Maintenance\
- (ESM)
-esm-infra     no        {dash}         UA Infra: Extended Security Maintenance\
- (ESM)
-fips          no        {dash}         NIST-certified core packages
-fips-updates  no        {dash}         NIST-certified core packages with\
- priority security updates
-livepatch     no        {dash}         Canonical Livepatch service
-ros           no        {dash}         Security Updates for the Robot\
- Operating System
-ros-updates   no        {dash}         All Updates for the Robot Operating\
- System
+SERVICE          ENTITLED  STATUS    DESCRIPTION
+esm-apps         no        {dash}         UA Apps: Extended Security Maintenance (ESM)
+esm-infra        no        {dash}         UA Infra: Extended Security Maintenance (ESM)
+fips             no        {dash}         NIST-certified core packages
+fips-updates     no        {dash}         NIST-certified core packages with priority security updates
+livepatch        no        {dash}         Canonical Livepatch service
+realtime-kernel  no        {dash}         Beta-version Ubuntu Kernel with PREEMPT_RT patches
+ros              no        {dash}         Security Updates for the Robot Operating System
+ros-updates      no        {dash}         All Updates for the Robot Operating System
 {notices}
 Enable services with: ua enable <service>
 
@@ -110,17 +105,15 @@ Enable services with: ua enable <service>
            Subscription: test_contract
             Valid until: 2040-05-08 19:02:26+00:00
 Technical support level: n/a
-"""
+"""  # noqa: E501
 
 # Omit beta services from status
 ATTACHED_STATUS_NOBETA = """\
-SERVICE       ENTITLED  STATUS    DESCRIPTION
-esm-infra     no        {dash}         UA Infra: Extended Security Maintenance\
- (ESM)
-fips          no        {dash}         NIST-certified core packages
-fips-updates  no        {dash}         NIST-certified core packages with\
- priority security updates
-livepatch     no        {dash}         Canonical Livepatch service
+SERVICE          ENTITLED  STATUS    DESCRIPTION
+esm-infra        no        {dash}         UA Infra: Extended Security Maintenance (ESM)
+fips             no        {dash}         NIST-certified core packages
+fips-updates     no        {dash}         NIST-certified core packages with priority security updates
+livepatch        no        {dash}         Canonical Livepatch service
 {notices}
 Enable services with: ua enable <service>
 
@@ -128,9 +121,9 @@ Enable services with: ua enable <service>
            Subscription: test_contract
             Valid until: 2040-05-08 19:02:26+00:00
 Technical support level: n/a
-"""
+"""  # noqa: E501
 
-BETA_SVC_NAMES = ["esm-apps", "ros", "ros-updates"]
+BETA_SVC_NAMES = ["esm-apps", "realtime-kernel", "ros", "ros-updates"]
 
 SERVICES_JSON_ALL = [
     {
@@ -185,6 +178,16 @@ SERVICES_JSON_ALL = [
         "available": "yes",
         "blocked_by": [],
     },
+    {
+        "description": "TODO",
+        "description_override": None,
+        "entitled": "no",
+        "name": "realtime-kernel",
+        "status": "—",
+        "status_details": "",
+        "available": "yes",
+        "blocked_by": [],
+    },
     {
         "description": "Security Updates for the Robot Operating System",
         "description_override": None,
@@ -257,14 +260,15 @@ Flags:
 )
 
 
+@mock.patch("uaclient.cli.contract.is_contract_changed", return_value=False)
 @mock.patch("uaclient.config.UAConfig.remove_notice")
 @mock.patch("uaclient.util.should_reboot", return_value=False)
 @mock.patch(
-    M_PATH + "contract.get_available_resources",
+    "uaclient.status.get_available_resources",
     return_value=RESPONSE_AVAILABLE_SERVICES,
 )
 @mock.patch(
-    M_PATH + "contract.get_contract_information",
+    "uaclient.status.get_contract_information",
     return_value=RESPONSE_CONTRACT_INFO,
 )
 @mock.patch(M_PATH + "os.getuid", return_value=0)
@@ -276,6 +280,7 @@ class TestActionStatus:
         _m_get_available_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         capsys,
     ):
         with pytest.raises(SystemExit):
@@ -302,6 +307,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         notices,
         notice_status,
         use_all,
@@ -340,6 +346,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         capsys,
         FakeConfig,
     ):
@@ -358,6 +365,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         capsys,
         FakeConfig,
     ):
@@ -383,6 +391,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         capsys,
         FakeConfig,
     ):
@@ -427,6 +436,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         use_all,
         environ,
         format_type,
@@ -536,6 +546,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         use_all,
         environ,
         format_type,
@@ -680,6 +691,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         use_all,
         format_type,
         event_logger_mode,
@@ -736,6 +748,14 @@ class TestActionStatus:
                 "entitled": "yes",
                 "name": "livepatch",
             },
+            {
+                "auto_enabled": "no",
+                "available": "no",
+                "description": "Beta-version Ubuntu Kernel with PREEMPT_RT"
+                " patches",
+                "entitled": "no",
+                "name": "realtime-kernel",
+            },
             {
                 "auto_enabled": "no",
                 "available": "no",
@@ -754,7 +774,7 @@ class TestActionStatus:
         ]
 
         if not use_all:
-            expected_services = expected_services[1:-2]
+            expected_services = expected_services[1:-3]
 
         expected = {
             "_doc": "Content provided in json response is currently considered"
@@ -803,6 +823,7 @@ class TestActionStatus:
         m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         FakeConfig,
     ):
         """Raise UrlError on connectivity issues"""
@@ -828,6 +849,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         encoding,
         expected_dash,
         FakeConfig,
@@ -878,6 +900,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         exception_to_throw,
         exception_type,
         exception_message,
@@ -928,6 +951,7 @@ class TestActionStatus:
         _m_get_avail_resources,
         _m_should_reboot,
         _m_remove_notice,
+        _m_contract_changed,
         format_type,
         event_logger_mode,
         token_to_use,
@@ -965,15 +989,63 @@ class TestActionStatus:
 
         assert output["errors"][0]["message"] == warning_message
 
+    @pytest.mark.parametrize(
+        "contract_changed,is_attached",
+        (
+            (False, True),
+            (True, False),
+            (True, True),
+            (False, False),
+        ),
+    )
+    @mock.patch(M_PATH_UACONFIG + "add_notice")
+    def test_is_contract_changed(
+        self,
+        m_add_notice,
+        _m_getuid,
+        _m_get_contract_information,
+        _m_get_available_resources,
+        _m_should_reboot,
+        _m_remove_notice,
+        _m_contract_changed,
+        contract_changed,
+        is_attached,
+        capsys,
+        FakeConfig,
+    ):
+        _m_contract_changed.return_value = contract_changed
+        if is_attached:
+            cfg = FakeConfig().for_attached_machine()
+        else:
+            cfg = FakeConfig()
+
+        action_status(
+            mock.MagicMock(all=False, simulate_with_token=None), cfg=cfg
+        )
+
+        if is_attached:
+            if contract_changed:
+                assert [
+                    mock.call("", messages.NOTICE_REFRESH_CONTRACT_WARNING)
+                ] == m_add_notice.call_args_list
+            else:
+                assert [
+                    mock.call("", messages.NOTICE_REFRESH_CONTRACT_WARNING)
+                ] not in m_add_notice.call_args_list
+        else:
+            assert _m_contract_changed.call_count == 0
+
 
 class TestStatusParser:
     @mock.patch(M_PATH + "contract.get_available_resources")
-    def test_status_parser_updates_parser_config(self, _m_resources):
+    def test_status_parser_updates_parser_config(
+        self, _m_resources, FakeConfig
+    ):
         """Update the parser configuration for 'status'."""
         m_parser = status_parser(mock.Mock())
         assert "status" == m_parser.prog
 
-        full_parser = get_parser()
+        full_parser = get_parser(FakeConfig())
         with mock.patch(
             "sys.argv",
             [
