@@ -15,6 +15,7 @@ from uaclient.contract import (
     UAContractClient,
     get_available_resources,
     get_contract_information,
+    is_contract_changed,
     process_entitlement_delta,
     request_updated_contract,
 )
@@ -126,6 +127,53 @@ class TestUAContractClient:
             mock.call("/v1/contracts/cId/context/machines/machineId", **params)
         ]
 
+    @pytest.mark.parametrize("machine_id_param", (("attach-machine-id")))
+    @pytest.mark.parametrize(
+        "machine_id_response", (("contract-machine-id"), None)
+    )
+    @pytest.mark.parametrize(
+        "detach,expected_http_method",
+        ((None, "POST"), (False, "POST"), (True, "DELETE")),
+    )
+    @pytest.mark.parametrize("activity_id", ((None), ("test-acid")))
+    @mock.patch("uaclient.contract.util.get_platform_info")
+    @mock.patch.object(UAContractClient, "_get_platform_data")
+    def test_get_updated_contract_info(
+        self,
+        m_platform_data,
+        get_platform_info,
+        get_machine_id,
+        request_url,
+        detach,
+        expected_http_method,
+        machine_id_response,
+        machine_id_param,
+        activity_id,
+        FakeConfig,
+    ):
+        def fake_platform_data(machine_id):
+            machine_id = "machine-id" if not machine_id else machine_id
+            return {"machineId": machine_id}
+
+        m_platform_data.side_effect = fake_platform_data
+        get_platform_info.return_value = {"arch": "arch", "kernel": "kernel"}
+        get_machine_id.return_value = "machineId"
+        machine_token = {"machineTokenInfo": {}}
+        if machine_id_response:
+            machine_token["machineTokenInfo"][
+                "machineId"
+            ] = machine_id_response
+        request_url.return_value = (machine_token, {})
+        kwargs = {
+            "machine_token": "mToken",
+            "contract_id": "cId",
+            "machine_id": machine_id_param,
+        }
+        cfg = FakeConfig.for_attached_machine()
+        client = UAContractClient(cfg)
+        resp = client.get_updated_contract_info(**kwargs)
+        assert resp == machine_token
+
     def test_request_resource_machine_access(
         self, get_machine_id, request_url, FakeConfig
     ):
@@ -293,7 +341,7 @@ class TestUAContractClient:
 
 
 class TestProcessEntitlementDeltas:
-    def test_error_on_missing_entitlement_type(self):
+    def test_error_on_missing_entitlement_type(self, FakeConfig):
         """Raise an error when neither dict contains entitlement type."""
         new_access = {"entitlement": {"something": "non-empty"}}
         error_msg = (
@@ -301,18 +349,22 @@ class TestProcessEntitlementDeltas:
             " {{}} {}".format(new_access)
         )
         with pytest.raises(exceptions.UserFacingError) as exc:
-            process_entitlement_delta({}, new_access)
+            process_entitlement_delta(
+                cfg=FakeConfig(), orig_access={}, new_access=new_access
+            )
         assert error_msg == str(exc.value.msg)
 
-    def test_no_delta_on_equal_dicts(self):
+    def test_no_delta_on_equal_dicts(self, FakeConfig):
         """No deltas are reported or processed when dicts are equal."""
         assert ({}, False) == process_entitlement_delta(
-            {"entitlement": {"no": "diff"}}, {"entitlement": {"no": "diff"}}
+            cfg=FakeConfig(),
+            orig_access={"entitlement": {"no": "diff"}},
+            new_access={"entitlement": {"no": "diff"}},
         )
 
     @mock.patch(M_REPO_PATH + "process_contract_deltas")
     def test_deltas_handled_by_entitlement_process_contract_deltas(
-        self, m_process_contract_deltas
+        self, m_process_contract_deltas, FakeConfig
     ):
         """Call entitlement.process_contract_deltas to handle any deltas."""
         m_process_contract_deltas.return_value = True
@@ -321,7 +373,9 @@ class TestProcessEntitlementDeltas:
         new_access["entitlement"]["newkey"] = "newvalue"
         expected = {"entitlement": {"newkey": "newvalue"}}
         assert (expected, True) == process_entitlement_delta(
-            original_access, new_access
+            cfg=FakeConfig(),
+            orig_access=original_access,
+            new_access=new_access,
         )
         expected_calls = [
             mock.call(original_access, expected, allow_enable=False)
@@ -329,12 +383,16 @@ class TestProcessEntitlementDeltas:
         assert expected_calls == m_process_contract_deltas.call_args_list
 
     @mock.patch(M_REPO_PATH + "process_contract_deltas")
-    def test_full_delta_on_empty_orig_dict(self, m_process_contract_deltas):
+    def test_full_delta_on_empty_orig_dict(
+        self, m_process_contract_deltas, FakeConfig
+    ):
         """Process and report full deltas on empty original access dict."""
         # Limit delta processing logic to handle attached state-A to state-B
         # Fresh installs will have empty/unset
         new_access = {"entitlement": {"type": "esm-infra", "other": "val2"}}
-        actual, _ = process_entitlement_delta({}, new_access)
+        actual, _ = process_entitlement_delta(
+            cfg=FakeConfig(), orig_access={}, new_access=new_access
+        )
         assert new_access == actual
         expected_calls = [mock.call({}, new_access, allow_enable=False)]
         assert expected_calls == m_process_contract_deltas.call_args_list
@@ -345,7 +403,7 @@ class TestProcessEntitlementDeltas:
     )
     @mock.patch(M_REPO_PATH + "process_contract_deltas")
     def test_overrides_applied_before_comparison(
-        self, m_process_contract_deltas, _
+        self, m_process_contract_deltas, _, FakeConfig
     ):
         old_access = {"entitlement": {"type": "esm", "some_key": "some_value"}}
         new_access = {
@@ -356,7 +414,9 @@ class TestProcessEntitlementDeltas:
             }
         }
 
-        process_entitlement_delta(old_access, new_access)
+        process_entitlement_delta(
+            cfg=FakeConfig(), orig_access=old_access, new_access=new_access
+        )
 
         assert 0 == m_process_contract_deltas.call_count
 
@@ -738,8 +798,11 @@ class TestRequestUpdatedContract:
         # of dict key ordering.
         process_calls = [
             mock.call(
-                {"entitlement": {"entitled": True, "type": "ent1"}},
-                {
+                cfg=cfg,
+                orig_access={
+                    "entitlement": {"entitled": True, "type": "ent1"}
+                },
+                new_access={
                     "entitlement": {
                         "entitled": True,
                         "type": "ent1",
@@ -750,10 +813,61 @@ class TestRequestUpdatedContract:
                 series_overrides=True,
             ),
             mock.call(
-                {"entitlement": {"entitled": False, "type": "ent2"}},
-                {"entitlement": {"entitled": False, "type": "ent2"}},
+                cfg=cfg,
+                orig_access={
+                    "entitlement": {"entitled": False, "type": "ent2"}
+                },
+                new_access={
+                    "entitlement": {"entitled": False, "type": "ent2"}
+                },
                 allow_enable=False,
                 series_overrides=True,
             ),
         ]
         assert process_calls == process_entitlement_delta.call_args_list
+
+
+@mock.patch("uaclient.contract.UAContractClient.get_updated_contract_info")
+class TestContractChanged:
+    @pytest.mark.parametrize("has_contract_expired", (False, True))
+    def test_contract_change_with_expiry(
+        self, get_updated_contract_info, has_contract_expired, FakeConfig
+    ):
+        if has_contract_expired:
+            expiry_date = "2041-05-08T19:02:26Z"
+            ret_val = True
+        else:
+            expiry_date = "2040-05-08T19:02:26Z"
+            ret_val = False
+        get_updated_contract_info.return_value = {
+            "machineTokenInfo": {
+                "contractInfo": {
+                    "effectiveTo": expiry_date,
+                },
+            },
+        }
+        cfg = FakeConfig().for_attached_machine()
+        assert is_contract_changed(cfg) == ret_val
+
+    @pytest.mark.parametrize("has_contract_changed", (False, True))
+    def test_contract_change_with_entitlements(
+        self, get_updated_contract_info, has_contract_changed, FakeConfig
+    ):
+        if has_contract_changed:
+            resourceEntitlements = [{"type": "token1", "entitled": True}]
+            resourceTokens = [{"token": "token1", "type": "resource1"}]
+        else:
+            resourceTokens = []
+            resourceEntitlements = []
+        get_updated_contract_info.return_value = {
+            "machineTokenInfo": {
+                "machineId": "test_machine_id",
+                "resourceTokens": resourceTokens,
+                "contractInfo": {
+                    "effectiveTo": "2040-05-08T19:02:26Z",
+                    "resourceEntitlements": resourceEntitlements,
+                },
+            },
+        }
+        cfg = FakeConfig().for_attached_machine()
+        assert is_contract_changed(cfg) == has_contract_changed
