@@ -7,10 +7,16 @@ import pytest
 
 from uaclient import exceptions
 from uaclient.clouds.identity import NoCloudTypeReason
+from uaclient.entitlements.entitlement_status import (
+    ApplicabilityStatus,
+    UserFacingStatus,
+)
 from uaclient.messages import (
     ENABLE_REBOOT_REQUIRED_TMPL,
     FAIL_X,
     OKGREEN_CHECK,
+    PROMPT_ENTER_TOKEN,
+    PROMPT_EXPIRED_ENTER_TOKEN,
     SECURITY_APT_NON_ROOT,
     SECURITY_ISSUE_NOT_RESOLVED,
     SECURITY_SERVICE_DISABLED,
@@ -41,13 +47,7 @@ from uaclient.security import (
     upgrade_packages_and_attach,
     version_cmp_le,
 )
-from uaclient.status import (
-    PROMPT_ENTER_TOKEN,
-    PROMPT_EXPIRED_ENTER_TOKEN,
-    ApplicabilityStatus,
-    UserFacingStatus,
-    colorize_commands,
-)
+from uaclient.status import colorize_commands
 
 M_PATH = "uaclient.contract."
 M_REPO_PATH = "uaclient.entitlements.repo.RepoEntitlement."
@@ -131,7 +131,7 @@ SAMPLE_USN_RESPONSE = {
     "instructions": "In general, a standard system update will make all ...\n",
     "references": [],
     "release_packages": {
-        "trusty": [
+        "series-example-1": [
             {
                 "description": "SMB/CIFS file, print, and login ... Unix",
                 "is_source": True,
@@ -146,7 +146,7 @@ SAMPLE_USN_RESPONSE = {
                 "version_link": "https://....11+dfsg-0ubuntu0.14.04.20+esm9",
             },
         ],
-        "bionic": [
+        "series-example-2": [
             {
                 "description": "high-level 3D graphics kit implementing ...",
                 "is_source": True,
@@ -405,7 +405,7 @@ class TestUSN:
         "series,expected",
         (
             (
-                "trusty",
+                "series-example-1",
                 {
                     "samba": {
                         "source": {
@@ -431,7 +431,7 @@ class TestUSN:
                 },
             ),
             (
-                "bionic",
+                "series-example-2",
                 {
                     "coin3": {
                         "source": {
@@ -454,7 +454,7 @@ class TestUSN:
                     }
                 },
             ),
-            ("focal", {}),
+            ("series-example-3", {}),
         ),
     )
     @mock.patch("uaclient.util.get_platform_info")
@@ -489,10 +489,10 @@ class TestUSN:
         self, get_platform_info, source_link, error_msg, FakeConfig
     ):
         """Raise errors when USN metadata contains no valid source_link."""
-        get_platform_info.return_value = {"series": "trusty"}
+        get_platform_info.return_value = {"series": "series-example-1"}
         client = UASecurityClient(FakeConfig())
         sparse_md = copy.deepcopy(SAMPLE_USN_RESPONSE)
-        sparse_md["release_packages"]["trusty"].append(
+        sparse_md["release_packages"]["series-example-1"].append(
             {
                 "is_source": False,
                 "name": "samba2",
@@ -897,21 +897,15 @@ class TestQueryInstalledPkgSources:
             ),
         ),
     )
-    @pytest.mark.parametrize("series", ("trusty", "bionic"))
     @mock.patch("uaclient.security.util.subp")
     @mock.patch("uaclient.util.get_platform_info")
     def test_result_keyed_by_source_package_name(
-        self, get_platform_info, subp, series, dpkg_out, results
+        self, get_platform_info, subp, dpkg_out, results
     ):
-        get_platform_info.return_value = {"series": series}
+        get_platform_info.return_value = {"series": "bionic"}
         subp.return_value = dpkg_out, ""
         assert results == query_installed_source_pkg_versions()
-        if series == "trusty":
-            _format = "-f=${Package},${Source},${Version},${Status}\n"
-        else:
-            _format = (
-                "-f=${Package},${Source},${Version},${db:Status-Status}\n"
-            )
+        _format = "-f=${Package},${Source},${Version},${db:Status-Status}\n"
         assert [
             mock.call(["dpkg-query", _format, "-W"])
         ] == subp.call_args_list
