@@ -10,6 +10,7 @@ from uaclient.defaults import (
     BASE_UA_URL,
     CONTRACT_EXPIRY_GRACE_PERIOD_DAYS,
 )
+from uaclient.entitlements.entitlement_status import ApplicationStatus
 from uaclient.jobs.update_messaging import (
     ContractExpiryStatus,
     ExternalMessage,
@@ -29,7 +30,6 @@ from uaclient.messages import (
     DISABLED_MOTD_NO_PKGS_TMPL,
     UBUNTU_NO_WARRANTY,
 )
-from uaclient.status import ApplicationStatus
 
 M_PATH = "uaclient.jobs.update_messaging."
 
@@ -102,7 +102,7 @@ class TestWriteAPTAndMOTDTemplates:
         infra_obj.application_status.return_value = (infra_status, "")
         infra_obj.name = "esm-infra"
 
-        def factory_side_effect(name):
+        def factory_side_effect(cfg, name):
             if name == "esm-infra":
                 return infra_cls
             if name == "esm-apps":
@@ -192,7 +192,7 @@ class TestWriteAPTAndMOTDTemplates:
         apps_obj = apps_cls.return_value
         apps_obj.name = "esm-apps"
 
-        def factory_side_effect(name):
+        def factory_side_effect(cfg, name):
             if name == "esm-infra":
                 return infra_cls
             if name == "esm-apps":
@@ -510,8 +510,6 @@ class TestWriteESMAnnouncementMessage:
         "series,release,is_active_esm,is_beta,cfg_allow_beta,"
         "apps_enabled,expected",
         (
-            # No ESM announcement when trusty
-            ("trusty", "14.04", True, False, True, False, None),
             # ESMApps.is_beta == True no Announcement
             ("xenial", "16.04", True, True, None, False, None),
             # Once release begins ESM and ESMApps.is_beta is false announce
