@@ -65,18 +65,6 @@ VERSION_CODENAME=xenial
 UBUNTU_CODENAME=xenial
 """
 
-OS_RELEASE_TRUSTY = """\
-NAME="Ubuntu"
-VERSION="14.04.5 LTS, Trusty Tahr"
-ID=ubuntu
-ID_LIKE=debian
-PRETTY_NAME="Ubuntu 14.04.5 LTS"
-VERSION_ID="14.04"
-HOME_URL="http://www.ubuntu.com/"
-SUPPORT_URL="http://help.ubuntu.com/"
-BUG_REPORT_URL="http://bugs.launchpad.net/ubuntu/"
-"""
-
 
 class TestGetDictDeltas:
     @pytest.mark.parametrize(
@@ -125,9 +113,8 @@ class TestIsLTS:
     @pytest.mark.parametrize(
         "series, supported_esm, expected",
         (
-            ("trusty", "trusty\nxenial\nbionic\nfocal", True),
-            ("xenial", "trusty\nxenial\nbionic\nfocal", True),
-            ("groovy", "trusty\nxenial\nbionic\nfocal", False),
+            ("xenial", "xenial\nbionic\nfocal", True),
+            ("groovy", "xenial\nbionic\nfocal", False),
         ),
     )
     @mock.patch("uaclient.util.subp")
@@ -146,7 +133,6 @@ class TestIsActiveESM:
     @pytest.mark.parametrize(
         "series, is_lts, days_until_esm,expected",
         (
-            ("trusty", True, 0, True),
             ("xenial", True, 1, False),
             ("xenial", True, 0, True),
             ("bionic", True, 1, False),
@@ -167,7 +153,7 @@ class TestIsActiveESM:
 
         # Use __wrapped__ to avoid hitting the lru_cached value across tests
         calls = []
-        if is_lts and series != "trusty":
+        if is_lts:
             calls.append(
                 mock.call(
                     [
@@ -295,22 +281,17 @@ class TestSubp:
             with pytest.raises(exceptions.ProcessExecutionError) as excinfo:
                 util.subp(["ls", "--bogus"])
 
-        expected_errors = [
-            "Failed running command 'ls --bogus' [exit(2)].",
-            "ls: unrecognized option '--bogus'",
-        ]
-        for msg in expected_errors:
-            assert msg in str(excinfo.value)
+        assert 2 == excinfo.value.exit_code
+        assert "" == excinfo.value.stdout
         assert 0 == m_sleep.call_count  # no retries
 
     @mock.patch("uaclient.util.time.sleep")
     def test_no_error_on_accepted_return_codes(self, m_sleep, _subp):
         """When rcs list includes the exit code, do not raise an error."""
         with mock.patch("uaclient.util._subp", side_effect=_subp):
-            out, err = util.subp(["ls", "--bogus"], rcs=[2])
+            out, _ = util.subp(["ls", "--bogus"], rcs=[2])
 
         assert "" == out
-        assert "ls: unrecognized option '--bogus'" in err
         assert 0 == m_sleep.call_count  # no retries
 
     @mock.patch("uaclient.util.time.sleep")
@@ -386,17 +367,19 @@ class TestParseOSRelease:
     def test_parse_os_release(self, caplog_text, tmpdir):
         """parse_os_release returns a dict of values from /etc/os-release."""
         release_file = tmpdir.join("os-release")
-        release_file.write(OS_RELEASE_TRUSTY)
+        release_file.write(OS_RELEASE_XENIAL)
         expected = {
             "BUG_REPORT_URL": "http://bugs.launchpad.net/ubuntu/",
             "HOME_URL": "http://www.ubuntu.com/",
             "ID": "ubuntu",
             "ID_LIKE": "debian",
             "NAME": "Ubuntu",
-            "PRETTY_NAME": "Ubuntu 14.04.5 LTS",
+            "PRETTY_NAME": "Ubuntu 16.04.5 LTS",
             "SUPPORT_URL": "http://help.ubuntu.com/",
-            "VERSION": "14.04.5 LTS, Trusty Tahr",
-            "VERSION_ID": "14.04",
+            "UBUNTU_CODENAME": "xenial",
+            "VERSION": "16.04.5 LTS (Xenial Xerus)",
+            "VERSION_CODENAME": "xenial",
+            "VERSION_ID": "16.04",
         }
         assert expected == util.parse_os_release(release_file.strpath)
         # Add a 2nd call for lru_cache test
@@ -432,7 +415,6 @@ class TestGetPlatformInfo:
     @pytest.mark.parametrize(
         "series,release,version,os_release_content",
         [
-            ("trusty", "14.04", "14.04 LTS (Trusty Tahr)", OS_RELEASE_TRUSTY),
             ("xenial", "16.04", "16.04 LTS (Xenial Xerus)", OS_RELEASE_XENIAL),
             (
                 "bionic",
@@ -474,57 +456,244 @@ class TestGetPlatformInfo:
                     assert expected == util.get_platform_info.__wrapped__()
 
 
-class TestApplySeriesOverrides:
+class TestApplyContractOverrides:
+    @pytest.mark.parametrize(
+        "override_selector,expected_weight",
+        (
+            ({"selector1": "valueX", "selector2": "valueZ"}, 0),
+            ({"selector1": "valueA", "selector2": "valueZ"}, 0),
+            ({"selector1": "valueX", "selector2": "valueB"}, 0),
+            ({"selector1": "valueA"}, 1),
+            ({"selector2": "valueB"}, 2),
+            ({"selector1": "valueA", "selector2": "valueB"}, 3),
+        ),
+    )
+    def test_get_override_weight(self, override_selector, expected_weight):
+        selector_values = {"selector1": "valueA", "selector2": "valueB"}
+        selector_weights = {"selector1": 1, "selector2": 2}
+        with mock.patch(
+            "uaclient.util.OVERRIDE_SELECTOR_WEIGHTS", selector_weights
+        ):
+            assert expected_weight == util._get_override_weight(
+                override_selector, selector_values
+            )
+
     def test_error_on_non_entitlement_dict(self):
         """Raise a runtime error when seeing invalid dict type."""
         with pytest.raises(RuntimeError) as exc:
-            util.apply_series_overrides({"some": "dict"})
+            util.apply_contract_overrides({"some": "dict"})
         error = (
             'Expected entitlement access dict. Missing "entitlement" key:'
             " {'some': 'dict'}"
         )
         assert error == str(exc.value)
 
+    @pytest.mark.parametrize("include_overrides", (True, False))
     @mock.patch(
-        "uaclient.util.get_platform_info", return_value={"series": "xenial"}
+        "uaclient.util.get_platform_info", return_value={"series": "ubuntuX"}
     )
-    def test_mutates_orig_access_dict(self, _):
-        """Mutate orig_access dict when called."""
+    @mock.patch(
+        "uaclient.clouds.identity.get_cloud_type", return_value=(None, "")
+    )
+    def test_return_same_dict_when_no_overrides_match(
+        self, _m_cloud_type, _m_platform_info, include_overrides
+    ):
         orig_access = {
             "entitlement": {
-                "a": {"a1": "av1", "a2": {"aa2": "aav2"}},
-                "b": "b1",
-                "c": "c1",
-                "series": {
-                    "trusty": {"a": "t1"},
-                    "xenial": {"a": {"a2": {"aa2": "xxv2"}}, "b": "bx1"},
-                },
+                "affordances": {"some_affordance": ["ubuntuX"]},
+                "directives": {"some_directive": ["ubuntuX"]},
+                "obligations": {"some_obligation": False},
             }
         }
+        # exactly the same
         expected = {
             "entitlement": {
-                "a": {"a1": "av1", "a2": {"aa2": "xxv2"}},
-                "b": "bx1",
-                "c": "c1",
+                "affordances": {"some_affordance": ["ubuntuX"]},
+                "directives": {"some_directive": ["ubuntuX"]},
+                "obligations": {"some_obligation": False},
             }
         }
-        util.apply_series_overrides(orig_access)
+        if include_overrides:
+            orig_access["entitlement"].update(
+                {
+                    "series": {
+                        "dontMatch": {
+                            "affordances": {
+                                "some_affordance": ["ubuntuX-series-overriden"]
+                            }
+                        }
+                    },
+                    "overrides": [
+                        {
+                            "selector": {"series": "dontMatch"},
+                            "affordances": {
+                                "some_affordance": ["ubuntuX-series-overriden"]
+                            },
+                        },
+                        {
+                            "selector": {"cloud": "dontMatch"},
+                            "affordances": {
+                                "some_affordance": ["ubuntuX-cloud-overriden"]
+                            },
+                        },
+                    ],
+                }
+            )
+
+        util.apply_contract_overrides(orig_access)
+        assert expected == orig_access
+
+    @mock.patch(
+        "uaclient.util.get_platform_info", return_value={"series": "ubuntuX"}
+    )
+    def test_missing_keys_are_included(self, _m_platform_info):
+        orig_access = {
+            "entitlement": {
+                "series": {"ubuntuX": {"directives": {"suites": ["ubuntuX"]}}}
+            }
+        }
+        expected = {"entitlement": {"directives": {"suites": ["ubuntuX"]}}}
+
+        util.apply_contract_overrides(orig_access)
+
+        assert expected == orig_access
+
+    @pytest.mark.parametrize(
+        "series_selector,cloud_selector,series_cloud_selector,expected_value",
+        (
+            # apply_overrides_when_only_series_match
+            ("no-match", "no-match", "no-match", "old_series_overriden"),
+            # series selector is applied over old series override
+            ("ubuntuX", "no-match", "no-match", "series_overriden"),
+            # cloud selector is applied over series override
+            ("no-match", "cloudX", "no-match", "cloud_overriden"),
+            # cloud selector is applied over series selector
+            ("ubuntuX", "cloudX", "no-match", "cloud_overriden"),
+            # cloud and series together are applied over others
+            ("ubuntuX", "cloudX", "cloudX", "both_overriden"),
+        ),
+    )
+    @mock.patch(
+        "uaclient.util.get_platform_info", return_value={"series": "ubuntuX"}
+    )
+    @mock.patch(
+        "uaclient.clouds.identity.get_cloud_type",
+        return_value=("cloudX", None),
+    )
+    def test_applies_contract_overrides_respecting_weight(
+        self,
+        _m_cloud_type,
+        _m_platform_info,
+        series_selector,
+        cloud_selector,
+        series_cloud_selector,
+        expected_value,
+    ):
+        """Apply the expected overrides to orig_access dict when called."""
+        orig_access = {
+            "entitlement": {
+                "affordances": {"some_affordance": ["original_affordance"]},
+                "series": {
+                    "ubuntuX": {
+                        "affordances": {
+                            "some_affordance": ["old_series_overriden"]
+                        }
+                    }
+                },
+                "overrides": [
+                    {
+                        "selector": {"series": series_selector},
+                        "affordances": {
+                            "some_affordance": ["series_overriden"]
+                        },
+                    },
+                    {
+                        "selector": {"cloud": cloud_selector},
+                        "affordances": {
+                            "some_affordance": ["cloud_overriden"]
+                        },
+                    },
+                    {
+                        "selector": {
+                            "series": series_selector,
+                            "cloud": series_cloud_selector,
+                        },
+                        "affordances": {"some_affordance": ["both_overriden"]},
+                    },
+                ],
+            }
+        }
+
+        expected = {
+            "entitlement": {
+                "affordances": {"some_affordance": [expected_value]}
+            }
+        }
+
+        util.apply_contract_overrides(orig_access)
         assert orig_access == expected
 
     @mock.patch(
-        "uaclient.util.get_platform_info", return_value={"series": "xenial"}
+        "uaclient.util.get_platform_info", return_value={"series": "ubuntuX"}
     )
-    def test_missing_keys_are_handled(self, _):
+    @mock.patch(
+        "uaclient.clouds.identity.get_cloud_type",
+        return_value=("cloudX", None),
+    )
+    def test_different_overrides_applied_together(
+        self, _m_cloud_type, _m_platform_info
+    ):
+        """Apply different overrides from different matching selectors."""
         orig_access = {
             "entitlement": {
-                "series": {"xenial": {"directives": {"suites": ["xenial"]}}}
+                "affordances": {"some_affordance": ["original_affordance"]},
+                "directives": {"some_directive": ["original_directive"]},
+                "obligations": {"some_obligation": False},
+                "series": {
+                    "ubuntuX": {
+                        "affordances": {
+                            "new_affordance": ["new_affordance_value"]
+                        }
+                    }
+                },
+                "overrides": [
+                    {
+                        "selector": {"series": "ubuntuX"},
+                        "affordances": {
+                            "some_affordance": ["series_overriden"]
+                        },
+                    },
+                    {
+                        "selector": {"cloud": "cloudX"},
+                        "directives": {"some_directive": ["cloud_overriden"]},
+                    },
+                    {
+                        "selector": {"series": "ubuntuX", "cloud": "cloudX"},
+                        "obligations": {
+                            "new_obligation": True,
+                            "some_obligation": True,
+                        },
+                    },
+                ],
             }
         }
-        expected = {"entitlement": {"directives": {"suites": ["xenial"]}}}
 
-        util.apply_series_overrides(orig_access)
+        expected = {
+            "entitlement": {
+                "affordances": {
+                    "new_affordance": ["new_affordance_value"],
+                    "some_affordance": ["series_overriden"],
+                },
+                "directives": {"some_directive": ["cloud_overriden"]},
+                "obligations": {
+                    "new_obligation": True,
+                    "some_obligation": True,
+                },
+            }
+        }
 
-        assert expected == orig_access
+        util.apply_contract_overrides(orig_access)
+        assert orig_access == expected
 
 
 class TestGetMachineId:
@@ -552,7 +721,7 @@ class TestGetMachineId:
     def test_get_machine_id_from_var_lib_dbus_machine_id(
         self, FakeConfig, tmpdir
     ):
-        """On trusty, machine id lives in of /var/lib/dbus/machine-id."""
+        """fallback to /var/lib/dbus/machine-id"""
         etc_machine_id = tmpdir.join("etc-machine-id")
         dbus_machine_id = tmpdir.join("dbus-machine-id")
         assert "/var/lib/dbus/machine-id" == util.DBUS_MACHINE_ID
@@ -1263,13 +1432,18 @@ class TestShouldReboot:
         assert 1 == m_load_file.call_count
 
     @pytest.mark.parametrize(
-        "installed_pkgs,reboot_required_pkgs,expected_ret",
+        "installed_pkgs,installed_pkgs_regex,reboot_required_pkgs,"
+        "expected_ret",
         (
-            (set(["a", "b", "c"]), "", False),
-            (set(["a", "b", "c"]), "a", True),
-            (set(["a", "b", "c"]), "a\ne", True),
-            (set(["a", "b", "c"]), "d\ne", False),
-            (None, "a\ne", True),
+            (set(["a", "b", "c"]), None, "", False),
+            (set(["a", "b", "c"]), None, "a", True),
+            (set(["a", "b", "c"]), None, "a\ne", True),
+            (set(["a", "b", "c"]), None, "d\ne", False),
+            (set(["a", "b", "c"]), set(["t.."]), "a\ne", True),
+            (set(["a", "b", "c"]), set(["t.."]), "one\ntwo", True),
+            (None, set(["^t..$"]), "one\ntwo", True),
+            (None, set(["^t..$"]), "one\nthree", False),
+            (None, None, "a\ne", True),
         ),
     )
     @mock.patch("os.path.exists")
@@ -1279,11 +1453,13 @@ class TestShouldReboot:
         m_load_file,
         m_path,
         installed_pkgs,
+        installed_pkgs_regex,
         reboot_required_pkgs,
         expected_ret,
     ):
         m_path.return_value = True
         m_load_file.return_value = reboot_required_pkgs
         assert expected_ret == util.should_reboot(
-            installed_pkgs=installed_pkgs
+            installed_pkgs=installed_pkgs,
+            installed_pkgs_regex=installed_pkgs_regex,
         )
